<?php

namespace Sukellos\Admin;

use Sukellos\Dao\WP_Scrapio_Gmap_Entities_Dao;
use Sukellos\ScrapioAPI\WP_Scrapio_API;
use Sukellos\ScrapioAPI\WP_Scrapio_API_Gmap_Search_Param;
use Sukellos\WP_Sukellos_Scrapio_Loader;
use Sukellos\WPFw\AdminBuilder\Item_Type;
use Sukellos\WPFw\WP_Plugin_Admin;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\Utils\WP_Log;
use Sukellos\WPFw\Singleton;
use Exception;

defined( 'ABSPATH' ) or exit;

/**
 * Admin class.
 *
 * @since 1.0.0
 */
class WP_Scrapio_Admin_Debug extends WP_Plugin_Admin {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {

        parent::init();

        add_action( 'wp_ajax_'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_debug_subscription', array( $this, 'execute_debug_subscription' ) );
        add_action( 'wp_ajax_'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_debug_gmap_types', array( $this, 'execute_debug_gmap_types' ) );
        add_action( 'wp_ajax_'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_debug_gmap_locations', array( $this, 'execute_debug_gmap_locations' ) );
        add_action( 'wp_ajax_'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_debug_gmap_place', array( $this, 'execute_debug_gmap_place' ) );
        add_action( 'wp_ajax_'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_debug_gmap_search', array( $this, 'execute_debug_gmap_search' ) );
        add_action( 'wp_ajax_'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_debug_gmap_enrich', array( $this, 'execute_debug_gmap_enrich' ) );
        add_action( 'wp_ajax_'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_debug_blacklist', array( $this, 'execute_debug_blacklist' ) );
        add_action( 'wp_ajax_'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_debug_blacklist_add', array( $this, 'execute_debug_blacklist_add' ) );
        add_action( 'wp_ajax_'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_debug_blacklist_delete', array( $this, 'execute_debug_blacklist_delete' ) );

        add_action( 'wp_ajax_'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_debug_extract_placeid', array( $this, 'execute_debug_extract_placeid' ) );
    }
        
    /***
     * AJAX Execute the execute_debug_extract_placeid
     */
    public function execute_debug_extract_placeid() {
                
        try {
            WP_Log::debug(__METHOD__, [], 'wp-sukellos-fw');

            // Load all entities from table lby_scrapio_gmap_entities
            $gmap_entities = WP_Scrapio_Gmap_Entities_Dao::instance()->get_gmap_entities( null, null, null, null, 'entity_id', 'ASC', 0, null );
            WP_Log::debug( __METHOD__.' Nb of gmap entities retrieved', [ 'Nb GMAP entities' => sizeof( $gmap_entities ) ], 'wp-sukellos-fw' );

            foreach ( $gmap_entities as $gmap_entity ) {

                $entity_id = $gmap_entity['entity_id'];

                // Get JSON data
                if ( !isset( $gmap_entity['entity_json'] ) || empty( $gmap_entity['entity_json'] ) ) {

                    WP_Log::warning( __METHOD__.' - Cannot import empty JSON data', [], 'wp-sukellos-fw' );
                    continue;
                }
                $entity_json = json_decode( $gmap_entity['entity_json'], true );
                WP_Log::debug( __METHOD__, ['$entity_json'=>$entity_json ], 'wp-sukellos-fw' );

                // Search for existing entity is made on Place_Id to ensure compatibility with Sukellos Google Annuaire
                $place_id = $entity_json['place_id'];

                // Update with place id extracted from JSON
                WP_Log::debug( __METHOD__. ' - update_gmap_entity ', ['$entity_id'=>$entity_id, '$place_id'=>$place_id ], 'wp-sukellos-fw' );
                WP_Scrapio_Gmap_Entities_Dao::instance()->update_gmap_entity(  $entity_id, null, null, $place_id, null, null, null, null, null, null, null, null );
            }

            wp_send_json_success( 'Success - '.sizeof( $gmap_entities ).' updates' );
            
        } catch (Exception $ex) {
            
            WP_Log::error(__METHOD__.' Error during product synchronization', ['code' => $ex->getCode(), 'message' => $ex->getMessage()], 'wp-sukellos-fw');
            wp_send_json_error('Error during request <br/> Code: '.$ex->getCode().' <br/> Message: '.$ex->getMessage().'<br/> See logging for more detailed informations.');
        }
        exit;
    }

    /***
     * AJAX Execute the execute_debug_subscription
     */
    public function execute_debug_subscription() {

        try {

            WP_Log::debug(__METHOD__, [], 'wp-sukellos-fw');

            // Request Scrap.io
            $raw_response = WP_Scrapio_API::instance()->subscription( true );

            // Send the JSon encoding of $results_array
            $output = print_r($raw_response, true);
            wp_send_json_success( '<pre style="font-size: 10px">'.$output.'</pre>' );

        } catch (Exception $ex) {

            WP_Log::error(__METHOD__.' Error during product synchronization', ['code' => $ex->getCode(), 'message' => $ex->getMessage()], 'wp-sukellos-fw');
            wp_send_json_error('Error during request <br/> Code: '.$ex->getCode().' <br/> Message: '.$ex->getMessage().'<br/> See logging for more detailed informations.');
        }
        exit;
    }

    /***
     * AJAX Execute the execute_debug_gmap_types
     */
    public function execute_debug_gmap_types() {

        try {

            WP_Log::debug(__METHOD__, [], 'wp-sukellos-fw');

            // Request Scrap.io
            $raw_response = WP_Scrapio_API::instance()->gmap_types( 'boulang', 'fr', true );

            // Send the JSon encoding of $results_array
            $output = print_r($raw_response, true);
            wp_send_json_success( '<pre style="font-size: 10px">'.$output.'</pre>' );

        } catch (Exception $ex) {

            WP_Log::error(__METHOD__.' Error during product synchronization', ['code' => $ex->getCode(), 'message' => $ex->getMessage()], 'wp-sukellos-fw');
            wp_send_json_error('Error during request <br/> Code: '.$ex->getCode().' <br/> Message: '.$ex->getMessage().'<br/> See logging for more detailed informations.');
        }
        exit;
    }

    /***
     * AJAX Execute the execute_debug_gmap_locations
     */
    public function execute_debug_gmap_locations() {

        try {

            WP_Log::debug(__METHOD__, [], 'wp-sukellos-fw');

            // Request Scrap.io
            $raw_response = WP_Scrapio_API::instance()->gmap_locations( 'fr', 'admin2', '', '', 'sav', true );

            // Send the JSon encoding of $results_array
            $output = print_r($raw_response, true);
            wp_send_json_success( '<pre style="font-size: 10px">'.$output.'</pre>' );

        } catch (Exception $ex) {

            WP_Log::error(__METHOD__.' Error during product synchronization', ['code' => $ex->getCode(), 'message' => $ex->getMessage()], 'wp-sukellos-fw');
            wp_send_json_error('Error during request <br/> Code: '.$ex->getCode().' <br/> Message: '.$ex->getMessage().'<br/> See logging for more detailed informations.');
        }
        exit;
    }

    /***
     * AJAX Execute the execute_debug_gmap_place
     */
    public function execute_debug_gmap_place() {

        try {

            WP_Log::debug(__METHOD__, [], 'wp-sukellos-fw');

            // Request Scrap.io
            $raw_response = WP_Scrapio_API::instance()->gmap_place( '0x35697592f4174c9:0x88a745d9be48d9d3', null, null, true );

            // Send the JSon encoding of $results_array
            $output = print_r($raw_response, true);
            wp_send_json_success( '<pre style="font-size: 10px">'.$output.'</pre>' );

        } catch (Exception $ex) {

            WP_Log::error(__METHOD__.' Error during product synchronization', ['code' => $ex->getCode(), 'message' => $ex->getMessage()], 'wp-sukellos-fw');
            wp_send_json_error('Error during request <br/> Code: '.$ex->getCode().' <br/> Message: '.$ex->getMessage().'<br/> See logging for more detailed informations.');
        }
        exit;
    }

    /***
     * AJAX Execute the execute_debug_gmap_search
     */
    public function execute_debug_gmap_search() {

        try {

            WP_Log::debug(__METHOD__, [], 'wp-sukellos-fw');

            // Request Scrap.io
            $args = array(
                WP_Scrapio_API_Gmap_Search_Param::COUNTRY_CODE => 'us',
                WP_Scrapio_API_Gmap_Search_Param::TYPE => 'restaurant',
                WP_Scrapio_API_Gmap_Search_Param::ADMIN1_CODE => 'NY',
                WP_Scrapio_API_Gmap_Search_Param::CITY => 'Adams',
            );
            $raw_response = WP_Scrapio_API::instance()->gmap_search( $args, true );

            // Send the JSon encoding of $results_array
            $output = print_r($raw_response, true);
            wp_send_json_success( '<pre style="font-size: 10px">'.$output.'</pre>' );

        } catch (Exception $ex) {

            WP_Log::error(__METHOD__.' Error during product synchronization', ['code' => $ex->getCode(), 'message' => $ex->getMessage()], 'wp-sukellos-fw');
            wp_send_json_error('Error during request <br/> Code: '.$ex->getCode().' <br/> Message: '.$ex->getMessage().'<br/> See logging for more detailed informations.');
        }
        exit;
    }

    /***
     * AJAX Execute the execute_debug_gmap_enrich
     */
    public function execute_debug_gmap_enrich() {

        try {

            WP_Log::debug(__METHOD__, [], 'wp-sukellos-fw');

            // Request Scrap.io
            $raw_response = WP_Scrapio_API::instance()->gmap_enrich( null, null, null, null, 'sukellos.com', null, null, true );

            // Send the JSon encoding of $results_array
            $output = print_r($raw_response, true);
            wp_send_json_success( '<pre style="font-size: 10px">'.$output.'</pre>' );

        } catch (Exception $ex) {

            WP_Log::error(__METHOD__.' Error during product synchronization', ['code' => $ex->getCode(), 'message' => $ex->getMessage()], 'wp-sukellos-fw');
            wp_send_json_error('Error during request <br/> Code: '.$ex->getCode().' <br/> Message: '.$ex->getMessage().'<br/> See logging for more detailed informations.');
        }
        exit;
    }

    /***
     * AJAX Execute the execute_debug_blacklist
     */
    public function execute_debug_blacklist() {

        try {

            WP_Log::debug(__METHOD__, [], 'wp-sukellos-fw');

            // Request Scrap.io
            $raw_response = WP_Scrapio_API::instance()->blacklist( true );

            // Send the JSon encoding of $results_array
            $output = print_r($raw_response, true);
            wp_send_json_success( '<pre style="font-size: 10px">'.$output.'</pre>' );

        } catch (Exception $ex) {

            WP_Log::error(__METHOD__.' Error during product synchronization', ['code' => $ex->getCode(), 'message' => $ex->getMessage()], 'wp-sukellos-fw');
            wp_send_json_error('Error during request <br/> Code: '.$ex->getCode().' <br/> Message: '.$ex->getMessage().'<br/> See logging for more detailed informations.');
        }
        exit;
    }

    /***
     * AJAX Execute the execute_debug_blacklist_add
     */
    public function execute_debug_blacklist_add() {

        try {

            WP_Log::debug(__METHOD__, [], 'wp-sukellos-fw');

            // Request Scrap.io
            $raw_response = WP_Scrapio_API::instance()->blacklist_add( 'sukellos-list', 'domain', 'sukellos.com', true );

            // Send the JSon encoding of $results_array
            $output = print_r($raw_response, true);
            wp_send_json_success( '<pre style="font-size: 10px">'.$output.'</pre>' );

        } catch (Exception $ex) {

            WP_Log::error(__METHOD__.' Error during product synchronization', ['code' => $ex->getCode(), 'message' => $ex->getMessage()], 'wp-sukellos-fw');
            wp_send_json_error('Error during request <br/> Code: '.$ex->getCode().' <br/> Message: '.$ex->getMessage().'<br/> See logging for more detailed informations.');
        }
        exit;
    }

    /***
     * AJAX Execute the execute_debug_blacklist_delete
     */
    public function execute_debug_blacklist_delete() {

        try {

            WP_Log::debug(__METHOD__, [], 'wp-sukellos-fw');

            // Request Scrap.io
            $raw_response = WP_Scrapio_API::instance()->blacklist_delete( 'sukellos-list', true );

            // Send the JSon encoding of $results_array
            $output = print_r($raw_response, true);
            wp_send_json_success( '<pre style="font-size: 10px">'.$output.'</pre>' );

        } catch (Exception $ex) {

            WP_Log::error(__METHOD__.' Error during product synchronization', ['code' => $ex->getCode(), 'message' => $ex->getMessage()], 'wp-sukellos-fw');
            wp_send_json_error('Error during request <br/> Code: '.$ex->getCode().' <br/> Message: '.$ex->getMessage().'<br/> See logging for more detailed informations.');
        }
        exit;
    }

    /**
     *          ===============
     *      =======================
     *  ============ HOOKS ===========
     *      =======================
     *          ===============
     */

    /***
     * Adding CSS and JS into header
     * Default add assets/admin.css and assets/admin.js
     */
    public function admin_enqueue_scripts() {}

    /***
     * Admin page
     * Settings managed by main Sukellos Fw Tools admin
     */
    public function create_items() {
        /*
        // Check if license restriction applied
        if ( $this->is_license_restricted() ) {

            return;
        }*/

        // To improve code readability
        $plugin_name = WP_Sukellos_Scrapio_Loader::instance()->get_name();
        $options_suffix_param = WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param();

        // Admin page.
        $admin_page = Admin_Builder::instance()->create_admin_page(
            array(
                'name' => $plugin_name.' - DEBUG',
                'title' => 'DEBUG',
                'id' => $options_suffix_param . '_debug',
                'capability' => 'manage_options',
                'parent_id' => $options_suffix_param.'_scrapio_admin_page',
                'icon' => 'dashicons-smiley', // Menu icon for top level menus only https://developer.wordpress.org/resource/dashicons/#editor-paste-word
                'position' => 30,
                'use_tabs' => true,
            )
        );

        $enable_debug = Admin_builder::get_option(WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_enable_debug', Item_Type::ENABLE);

        if ( $enable_debug ) {

            $tab1 = $admin_page->create_tab(
                array(
                    'name' => 'subscription'
                )
            );

            // Create an AJAX button
            $tab1->create_ajax_button(
                array(
                    // Common
                    'id' => $options_suffix_param.'_debug_subscription_ajax_button',
                    'name' => __( 'subscription', 'wp-sukellos-fw' ),
                    'desc' => __( 'Call GET https://scrap.io/api/v1/subscription using AJAX.', 'wp-sukellos-fw' ),
                    // Specific
                    'action' => $options_suffix_param . '_debug_subscription',
                    'label' => __( 'subscription', 'wp-sukellos-fw' ),
                    'button_class' => 'button-secondary',
                    'wait_label' => __( 'Processing...', 'wp-sukellos-fw' ),
                    'success_label' => __( 'Success', 'wp-sukellos-fw' ),
                    'error_label' => __( 'Error', 'wp-sukellos-fw' ),
                    'success_callback' => '',
                    'error_callback' => '',
                    'data_filter_callback' => '',
                    'ajax_result_container' => 'subscription_result', // Auto create a div to display result
                    'sukellos_rule_exception' => true,
                )
            );

            $tab2 = $admin_page->create_tab(
                array(
                    'name' => 'gmap/types'
                )
            );

            // Create an AJAX button
            $tab2->create_ajax_button(
                array(
                    // Common
                    'id' => $options_suffix_param.'_debug_gmap_types_ajax_button',
                    'name' => __( 'gmap/types', 'wp-sukellos-fw' ),
                    'desc' => __( 'Call GET https://scrap.io/api/v1/gmap/types using AJAX (params : search_term = "boulang", locale = "fr")', 'wp-sukellos-fw' ),
                    // Specific
                    'action' => $options_suffix_param . '_debug_gmap_types',
                    'label' => __( 'gmap/types', 'wp-sukellos-fw' ),
                    'button_class' => 'button-secondary',
                    'wait_label' => __( 'Processing...', 'wp-sukellos-fw' ),
                    'success_label' => __( 'Success', 'wp-sukellos-fw' ),
                    'error_label' => __( 'Error', 'wp-sukellos-fw' ),
                    'success_callback' => '',
                    'error_callback' => '',
                    'data_filter_callback' => '',
                    'ajax_result_container' => 'gmap_types_result', // Auto create a div to display result
                    'sukellos_rule_exception' => true,
                )
            );

            $tab3 = $admin_page->create_tab(
                array(
                    'name' => 'gmap/locations'
                )
            );

            // Create an AJAX button
            $tab3->create_ajax_button(
                array(
                    // Common
                    'id' => $options_suffix_param.'_debug_gmap_locations_ajax_button',
                    'name' => __( 'gmap/locations', 'wp-sukellos-fw' ),
                    'desc' => __( 'Call GET https://scrap.io/api/v1/gmap/locations using AJAX (params : country_code = "fr", type = "admin2", search_term = "sav")', 'wp-sukellos-fw' ),
                    // Specific
                    'action' => $options_suffix_param . '_debug_gmap_locations',
                    'label' => __( 'gmap/locations', 'wp-sukellos-fw' ),
                    'button_class' => 'button-secondary',
                    'wait_label' => __( 'Processing...', 'wp-sukellos-fw' ),
                    'success_label' => __( 'Success', 'wp-sukellos-fw' ),
                    'error_label' => __( 'Error', 'wp-sukellos-fw' ),
                    'success_callback' => '',
                    'error_callback' => '',
                    'data_filter_callback' => '',
                    'ajax_result_container' => 'gmap_locations_result', // Auto create a div to display result
                    'sukellos_rule_exception' => true,
                )
            );

            $tab4 = $admin_page->create_tab(
                array(
                    'name' => 'gmap/place'
                )
            );

            // Create an AJAX button
            $tab4->create_ajax_button(
                array(
                    // Common
                    'id' => $options_suffix_param.'_debug_gmap_place_ajax_button',
                    'name' => __( 'gmap/place', 'wp-sukellos-fw' ),
                    'desc' => __( 'Call GET https://scrap.io/api/v1/gmap/place using AJAX (params : google_id = "0x35697592f4174c9:0x88a745d9be48d9d3")', 'wp-sukellos-fw' ),
                    // Specific
                    'action' => $options_suffix_param . '_debug_gmap_place',
                    'label' => __( 'gmap/place', 'wp-sukellos-fw' ),
                    'button_class' => 'button-secondary',
                    'wait_label' => __( 'Processing...', 'wp-sukellos-fw' ),
                    'success_label' => __( 'Success', 'wp-sukellos-fw' ),
                    'error_label' => __( 'Error', 'wp-sukellos-fw' ),
                    'success_callback' => '',
                    'error_callback' => '',
                    'data_filter_callback' => '',
                    'ajax_result_container' => 'gmap_place_result', // Auto create a div to display result
                    'sukellos_rule_exception' => true,
                )
            );

            $tab5 = $admin_page->create_tab(
                array(
                    'name' => 'gmap/search'
                )
            );

            // Create an AJAX button
            $tab5->create_ajax_button(
                array(
                    // Common
                    'id' => $options_suffix_param.'_debug_gmap_search_ajax_button',
                    'name' => __( 'gmap/search', 'wp-sukellos-fw' ),
                    'desc' => __( 'Call GET https://scrap.io/api/v1/gmap/search using AJAX (params : "country_code" => "us", "admin1_code" => "NY", "city" => "Adams", "type" => "restaurant")', 'wp-sukellos-fw' ),
                    // Specific
                    'action' => $options_suffix_param . '_debug_gmap_search',
                    'label' => __( 'gmap/search', 'wp-sukellos-fw' ),
                    'button_class' => 'button-secondary',
                    'wait_label' => __( 'Processing...', 'wp-sukellos-fw' ),
                    'success_label' => __( 'Success', 'wp-sukellos-fw' ),
                    'error_label' => __( 'Error', 'wp-sukellos-fw' ),
                    'success_callback' => '',
                    'error_callback' => '',
                    'data_filter_callback' => '',
                    'ajax_result_container' => 'gmap_search_result', // Auto create a div to display result
                    'sukellos_rule_exception' => true,
                )
            );

            $tab6 = $admin_page->create_tab(
                array(
                    'name' => 'gmap/enrich'
                )
            );

            // Create an AJAX button
            $tab6->create_ajax_button(
                array(
                    // Common
                    'id' => $options_suffix_param.'_debug_gmap_enrich_ajax_button',
                    'name' => __( 'gmap/enrich', 'wp-sukellos-fw' ),
                    'desc' => __( 'Call GET https://scrap.io/api/v1/gmap/enrich using AJAX (params : "domain" => "sukellos.com")', 'wp-sukellos-fw' ),
                    // Specific
                    'action' => $options_suffix_param . '_debug_gmap_enrich',
                    'label' => __( 'gmap/enrich', 'wp-sukellos-fw' ),
                    'button_class' => 'button-secondary',
                    'wait_label' => __( 'Processing...', 'wp-sukellos-fw' ),
                    'success_label' => __( 'Success', 'wp-sukellos-fw' ),
                    'error_label' => __( 'Error', 'wp-sukellos-fw' ),
                    'success_callback' => '',
                    'error_callback' => '',
                    'data_filter_callback' => '',
                    'ajax_result_container' => 'gmap_enrich_result', // Auto create a div to display result
                    'sukellos_rule_exception' => true,
                )
            );

            $tab7 = $admin_page->create_tab(
                array(
                    'name' => 'blacklist'
                )
            );

            // Create an AJAX button
            $tab7->create_ajax_button(
                array(
                    // Common
                    'id' => $options_suffix_param.'_debug_blacklist_ajax_button',
                    'name' => __( 'blacklist', 'wp-sukellos-fw' ),
                    'desc' => __( 'Call GET https://scrap.io/api/v1/blacklist using AJAX)', 'wp-sukellos-fw' ),
                    // Specific
                    'action' => $options_suffix_param . '_debug_blacklist',
                    'label' => __( 'blacklist', 'wp-sukellos-fw' ),
                    'button_class' => 'button-secondary',
                    'wait_label' => __( 'Processing...', 'wp-sukellos-fw' ),
                    'success_label' => __( 'Success', 'wp-sukellos-fw' ),
                    'error_label' => __( 'Error', 'wp-sukellos-fw' ),
                    'success_callback' => '',
                    'error_callback' => '',
                    'data_filter_callback' => '',
                    'ajax_result_container' => 'blacklist_result', // Auto create a div to display result
                    'sukellos_rule_exception' => true,
                )
            );

            $tab8 = $admin_page->create_tab(
                array(
                    'name' => 'blacklist add'
                )
            );

            // Create an AJAX button
            $tab8->create_ajax_button(
                array(
                    // Common
                    'id' => $options_suffix_param.'_debug_blacklist_add_ajax_button',
                    'name' => __( 'blacklist add', 'wp-sukellos-fw' ),
                    'desc' => __( 'Call POST https://scrap.io/api/v1/blacklist/{list-name} using AJAX (params : "list_name" => "sukellos", "type" => "domain", "data" => "sukellos.com"). No _ in list name.', 'wp-sukellos-fw' ),
                    // Specific
                    'action' => $options_suffix_param . '_debug_blacklist_add',
                    'label' => __( 'blacklist_add', 'wp-sukellos-fw' ),
                    'button_class' => 'button-secondary',
                    'wait_label' => __( 'Processing...', 'wp-sukellos-fw' ),
                    'success_label' => __( 'Success', 'wp-sukellos-fw' ),
                    'error_label' => __( 'Error', 'wp-sukellos-fw' ),
                    'success_callback' => '',
                    'error_callback' => '',
                    'data_filter_callback' => '',
                    'ajax_result_container' => 'blacklist_add_result', // Auto create a div to display result
                    'sukellos_rule_exception' => true,
                )
            );

            $tab9 = $admin_page->create_tab(
                array(
                    'name' => 'blacklist delete'
                )
            );

            // Create an AJAX button
            $tab9->create_ajax_button(
                array(
                    // Common
                    'id' => $options_suffix_param.'_debug_blacklist_delete_ajax_button',
                    'name' => __( 'blacklist delete', 'wp-sukellos-fw' ),
                    'desc' => __( 'Call DELETE https://scrap.io/api/v1/blacklist/{list-name} using AJAX (params : "list_name" => "sukellos"). No _ in list name.', 'wp-sukellos-fw' ),
                    // Specific
                    'action' => $options_suffix_param . '_debug_blacklist_delete',
                    'label' => __( 'blacklist_delete', 'wp-sukellos-fw' ),
                    'button_class' => 'button-secondary',
                    'wait_label' => __( 'Processing...', 'wp-sukellos-fw' ),
                    'success_label' => __( 'Success', 'wp-sukellos-fw' ),
                    'error_label' => __( 'Error', 'wp-sukellos-fw' ),
                    'success_callback' => '',
                    'error_callback' => '',
                    'data_filter_callback' => '',
                    'ajax_result_container' => 'blacklist_delete_result', // Auto create a div to display result
                    'sukellos_rule_exception' => true,
                )
            );

/*
            // Create an AJAX button
            $tab9->create_ajax_button(
                array(
                    // Common
                    'id' => $options_suffix_param.'_debug_extract_placeid_ajax_button',
                    'name' => __( 'extract_placeid', 'wp-sukellos-fw' ),
                    'desc' => '',
                    // Specific
                    'action' => $options_suffix_param . '_debug_extract_placeid',
                    'label' => __( 'extract_placeid', 'wp-sukellos-fw' ),
                    'button_class' => 'button-secondary',
                    'wait_label' => __( 'Processing...', 'wp-sukellos-fw' ),
                    'success_label' => __( 'Success', 'wp-sukellos-fw' ),
                    'error_label' => __( 'Error', 'wp-sukellos-fw' ),
                    'success_callback' => '',
                    'error_callback' => '',
                    'data_filter_callback' => '',
                    'ajax_result_container' => 'debug_extract_placeid_result', // Auto create a div to display result
                    'sukellos_rule_exception' => true,
                )
            );*/
        }
    }
}