<?php

namespace Sukellos\Admin;

use Sukellos\WP_Scrapio_Searches_List_Table;
use Sukellos\WP_Sukellos_Scrapio_Loader;
use Sukellos\WPFw\AdminBuilder\Item_Type;
use Sukellos\WPFw\Utils\WP_Log;
use Sukellos\WPFw\WP_Plugin_Admin;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\Singleton;

defined( 'ABSPATH' ) or exit;

/**
 * Admin class.
 *
 * @since 1.0.0
 */
class WP_Scrapio_Admin_Searches extends WP_Plugin_Admin {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {

        parent::init();

        add_filter( 'sukellos_fw/admin_builder/field/'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_searches_list_content', array( $this, 'filter_field_searches_list_content' ), 10 ,1 );

    }

    /**
     *          ===============
     *      =======================
     *  ============ HOOKS ===========
     *      =======================
     *          ===============
     */


    /***
     * Adding CSS and JS into header
     * Default add assets/admin.css and assets/admin.js
     */
    public function admin_enqueue_scripts() {
    }

    /**
     * Allow to add content that can be treted only after admin_menu hook execution context
     *
     * @param $content content that can be enriched
     * @return mixed
     *
     * @since 1.3.2
     */
    public function filter_field_searches_list_content( $content ) {

        WP_Log::debug( __METHOD__, ['$content'=>$content, '$_POST'=>$_POST], 'wp-sukellos-fw');

        // Tip to keep POST available in filter
        //$_POST = $this->saved_post;

        $this->wp_scrapio_searches_list_table = new WP_Scrapio_Searches_List_Table();
        $this->wp_scrapio_searches_list_table->prepare_items();

        ob_start();
        $this->wp_scrapio_searches_list_table->display_result_message();

        echo '
            <form method="post">
                <input type="hidden" name="page" value="'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_entities_list'.'">';

        $this->wp_scrapio_searches_list_table->search_box('search', 'search_id');
        $this->wp_scrapio_searches_list_table->display();

        wp_nonce_field('bulk-entities');
        echo '
            </form>
        ';
        $html_content = ob_get_clean();

        return $html_content;
    }

    /***
     * Admin page
     * Settings managed by main Sukellos Fw Tools admin
     */
    public function create_items()
    {
        // To improve code readability
        $plugin_name = WP_Sukellos_Scrapio_Loader::instance()->get_name();
        $options_suffix_param = WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param();
/*
        // Check if license restriction applied
        if ( $this->is_license_restricted() ) {

            // Admin page.
            $admin_page = Admin_Builder::instance()->create_admin_page(
                array(
                    'name' => $plugin_name.' - '.__( 'Settings', 'wp-sukellos-fw' ),
                    'title' => __( 'Settings', 'wp-sukellos-fw' ),
                    'id' => $options_suffix_param . '_settings',
                    'capability' => 'manage_options',
                    'parent_id' => $options_suffix_param.'_scrapio_admin_page',
                    'icon' => 'dashicons-smiley', // Menu icon for top level menus only https://developer.wordpress.org/resource/dashicons/#editor-paste-word
                    'position' => 27,
                    'use_tabs' => false,
                )
            );

            // Create a note
            $admin_page->create_note(
                array(
                    // Common
                    'id' => $options_suffix_param.'_note_license_invalid2',
                    'name' => __( 'ATTENTION', 'wp-sukellos-fw' ),
                    'desc' => __( 'Thank you to validate your license, in order to be able to use all the functionalities of this plugin. If you do not yet have a license key, you can purchase one <a href="'.WP_Sukellos_Scrapio_Loader::instance()->get_sales_page_url().'" target="_blank">here</a>', 'wp-sukellos-fw' ),
                    'sukellos_rule_exception' => true,
                )
            );
            return;
        }
*/
        // Admin page.
        $admin_page = Admin_Builder::instance()->create_admin_page(
            array(
                'name' => $plugin_name.' - '.__( 'Import Logs', 'wp-sukellos-fw' ),
                'title' => __( 'Import Logs', 'wp-sukellos-fw' ),
                'id' => $options_suffix_param . '_searches',
                'capability' => 'manage_options',
                'parent_id' => $options_suffix_param.'_scrapio_admin_page',
                'icon' => 'dashicons-smiley', // Menu icon for top level menus only https://developer.wordpress.org/resource/dashicons/#editor-paste-word
                'position' => 23,
                'desc' => __( 'List of previously gmap searches from Scrap.io', 'wp-sukellos-fw' ),
            )
        );

        // This content will be filled by its self filter: sukellos_fw/admin_builder/field/'.WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_header_crud_gmap_entities_list_content
        $admin_page->create_content(
            array(
                'id' => $options_suffix_param . '_searches_list_content',
                'name' => __( 'Gmap Searches List', 'wp-sukellos-fw' ),
                'content' => '',
            )
        );
    }

}