<?php

namespace Sukellos\Admin;

use Sukellos\WP_Scrapio_CPT_Mapper;
use Sukellos\WP_Sukellos_Scrapio_Loader;
use Sukellos\WPFw\Utils\WP_Log;
use Sukellos\WPFw\WP_Plugin_Admin;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\AdminBuilder\Item_Type;
use Sukellos\WPFw\Singleton;
use Exception;

defined( 'ABSPATH' ) or exit;

/**
 * Admin class.
 *
 * @since 1.0.0
 */
class WP_Scrapio_Admin_Settings extends WP_Plugin_Admin {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {

        parent::init();
    }

    /**
     *          ===============
     *      =======================
     *  ============ HOOKS ===========
     *      =======================
     *          ===============
     */

    /***
     * Adding CSS and JS into header
     * Default add assets/admin.css and assets/admin.js
     */
    public function admin_enqueue_scripts() {}

    /***
     * Admin page
     * Settings managed by main Sukellos Fw Tools admin
     */
    public function create_items()
    {
        // To improve code readability
        $plugin_name = WP_Sukellos_Scrapio_Loader::instance()->get_name();
        $options_suffix_param = WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param();
/*
        // Check if license restriction applied
        if ( $this->is_license_restricted() ) {

            // Admin page.
            $admin_page = Admin_Builder::instance()->create_admin_page(
                array(
                    'name' => $plugin_name.' - '.__( 'Settings', 'wp-sukellos-fw' ),
                    'title' => __( 'Settings', 'wp-sukellos-fw' ),
                    'id' => $options_suffix_param . '_settings',
                    'capability' => 'manage_options',
                    'parent_id' => $options_suffix_param.'_scrapio_admin_page',
                    'icon' => 'dashicons-smiley', // Menu icon for top level menus only https://developer.wordpress.org/resource/dashicons/#editor-paste-word
                    'position' => 27,
                    'use_tabs' => false,
                )
            );

            // Create a note
            $admin_page->create_note(
                array(
                    // Common
                    'id' => $options_suffix_param.'_note_license_invalid2',
                    'name' => __( 'ATTENTION', 'wp-sukellos-fw' ),
                    'desc' => __( 'Thank you to validate your license, in order to be able to use all the functionalities of this plugin. If you do not yet have a license key, you can purchase one <a href="'.WP_Sukellos_Scrapio_Loader::instance()->get_sales_page_url().'" target="_blank">here</a>', 'wp-sukellos-fw' ),
                    'sukellos_rule_exception' => true,
                )
            );
            return;
        }
*/
        // Admin page.
        $admin_page = Admin_Builder::instance()->create_admin_page(
            array(
                'name' => $plugin_name.' - '.__( 'Settings', 'wp-sukellos-fw' ),
                'title' => __( 'Settings', 'wp-sukellos-fw' ),
                'id' => $options_suffix_param . '_settings',
                'capability' => 'manage_options',
                'parent_id' => $options_suffix_param.'_scrapio_admin_page',
                'icon' => 'dashicons-smiley', // Menu icon for top level menus only https://developer.wordpress.org/resource/dashicons/#editor-paste-word
                'position' => 21,
                'use_tabs' => true,
            )
        );

        // Import config
        $import_config_tab = $admin_page->create_tab(
            array(
                'name' => 'Import config'
            )
        );

        $import_config_tab->create_header(
            array(
                'id' => $options_suffix_param.'_header_import_config',
                'name' => __( 'Import config', 'wp-sukellos-fw' ),
                'desc' => __( 'Configuration for Scrap.io import. Will be used for all imports', 'wp-sukellos-fw' ),
            )
        );

        $import_config_tab->create_option(
            array(
                'type' => Item_type::ENABLE,
                'id'      => $options_suffix_param.'_enable_caching',
                'name'    => __( 'Activate the caching mode', 'wp-sukellos-fw' ),
                'desc'    => __( 'Enable/disable cache mode to avoid repeating identical or more specific requests. For example, if cache mode is enabled and a request has already been made for FR/Bretagne, the request for FR/Bretagne will not be replayed, nor will the more specific request FR/Bretagne/Finistère, since the results for Finistère are already stored. This helps to save Scrap.io credits.', 'wp-sukellos-fw' ),
                'default' => false
            )
        );

        $import_config_tab->create_option(
            array(
                'type' => Item_type::ENABLE,
                'id'      => $options_suffix_param.'_update_same_entity',
                'name'    => __( 'Activate the updating mode', 'wp-sukellos-fw' ),
                'desc'    => __( 'Enable/disable updating mode to force an already existing Gmap entity to be updated each time a request is made.', 'wp-sukellos-fw' ),
                'default' => false
            )
        );



        // Import config
        $mapping_tab = $admin_page->create_tab(
            array(
                'name' => 'CPT Mapping'
            )
        );

        $mapping_tab->create_header(
            array(
                'id' => $options_suffix_param.'_header_cpt_mapping',
                'name' => __( 'CPT Mapping', 'wp-sukellos-fw' ),
                'desc' => __( 'Configuration of mapping between Scrap.io gmap data and WordPress custom fields', 'wp-sukellos-fw' ),
            )
        );

        // Gets a list of all registered post type objects.
        $args = array(
            'public'   => true,
            '_builtin' => false
        );
        $post_types = get_post_types( $args, 'names', 'and' );
        WP_Log::debug( __METHOD__, ['$post_types'=>$post_types], 'wp-sukellos-fw' );

        // Create an multicheck option field
        $mapping_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_gmap_entities_cpt_type',
                'name' => __( 'CPT type for Gmap entity', 'wp-sukellos-fw' ),
                'desc' => __( 'Please select the Custom Post Type to be associated with Gmap imported entities from Scrap.io', 'wp-sukellos-fw' ),
                'hidden' => false,
                // Specific
                'options' => $post_types,
                'multiple' => false, // Set to true to use advanced multiple selection
            )
        );

        $mapping_tab->create_option(
            array(
                'type' => Item_type::ENABLE,
                'id'      => $options_suffix_param.'_enable_acf_field_keys',
                'name'    => __( 'Activate the Gmap ACF fields', 'wp-sukellos-fw' ),
                'desc'    => __( 'Enable/disable the ACF fields support for GMAP entities.', 'wp-sukellos-fw' ),
                'default' => false
            )
        );
        $enable_acf_field_keys = Admin_builder::get_option(WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param().'_enable_acf_field_keys', Item_Type::ENABLE);

        if ( $enable_acf_field_keys ) {

            // Get images sizes and prepare options
            $options = array();
            foreach ( WP_Scrapio_CPT_Mapper::SUPPORTED_FIELD_KEYS as $field_key ) {

                $options[ $field_key ] = $field_key;
            }

            // Create an multicheck option field
            $mapping_tab->create_option(
                array(
                    'type' => Item_Type::MULTICHECK,
                    // Common
                    'id' => $options_suffix_param.'_supported_field_keys',
                    'name' => __( 'Supported Gmap ACF fields', 'wp-sukellos-fw' ),
                    'desc' => __( 'Uncheck the GMAP entities fields you do not wish to import as ACF field.', 'wp-sukellos-fw' ),
                    'options' => $options,

                    'default' => array_keys( $options ),
                    'select_all' => __( 'Select all', 'wp-sukellos-fw' ), // Display a select all checkbox if true, or a string which define the label
                )
            );
        }

        $mapping_tab->create_option(
            array(
                'type' => Item_type::ENABLE,
                'id'      => $options_suffix_param.'_enable_acf_working_hours_field_key',
                'name'    => __( 'Activate the Gmap Working Hours ACF field', 'wp-sukellos-fw' ),
                'desc'    => __( 'Enable/disable the Working Hours ACF field support for GMAP entities.', 'wp-sukellos-fw' ),
                'default' => false
            )
        );


        // Gmap Search parameters
        $gmap_search_tab = $admin_page->create_tab(
            array(
                'name' => 'gmap/search params'
            )
        );

        $gmap_search_tab->create_header(
            array(
                'id' => $options_suffix_param.'_header_gmap_search_params',
                'name' => __( 'gmap/search params', 'wp-sukellos-fw' ),
                'desc' => __( 'Detailed parameters used for gmap/search request', 'wp-sukellos-fw' ),
            )
        );

        // Create an multicheck option field
        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_per_page',
                'name' => 'Per page',
                'desc' => 'Number of results per page (1, 10, 25 or 50).',
                'default' => array('per_page_not_set'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'per_page_all' => __( 'All', 'wp-sukellos-fw' ),
                    'per_page_1' => '1',
                    'per_page_10' => '10',
                    'per_page_25' => '25',
                    'per_page_50' => '50',
                ),
                'multiple' => false, // Set to true to use advanced multiple selection
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::ENABLE,
                'id'      => $options_suffix_param.'_skip_data',
                'name'    => __( 'Skip data', 'wp-sukellos-fw' ),
                'desc'    => __( 'Boolean (0 = false / 1 = true) to indicate that you want to skip the data part of the response. When the data is skipped, it won\'t deduct any export credit.', 'wp-sukellos-fw' ),
                'default' => false
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_cursor',
                'name' => __( 'Cursor', 'wp-sukellos-fw' ),
                'desc' => __( 'Cursor pagination', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_gmap_is_main_type',
                'name' => 'Gmap is main type',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('gmap_is_main_type_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'gmap_is_main_type_all' => __( 'All', 'wp-sukellos-fw' ),
                    'gmap_is_main_type_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'gmap_is_main_type_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_gmap_is_closed',
                'name' => 'Gmap is closed',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('gmap_is_closed_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'gmap_is_closed_all' => __( 'All', 'wp-sukellos-fw' ),
                    'gmap_is_closed_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'gmap_is_closed_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_gmap_has_website',
                'name' => 'Gmap has website',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('gmap_has_website_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'gmap_has_website_all' => __( 'All', 'wp-sukellos-fw' ),
                    'gmap_has_website_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'gmap_has_website_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_gmap_has_phone',
                'name' => 'Gmap has phone',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('gmap_has_phone_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'gmap_has_phone_all' => __( 'All', 'wp-sukellos-fw' ),
                    'gmap_has_phone_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'gmap_has_phone_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        // Create an multicheck option field
        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_gmap_price_range',
                'name' => 'Gmap price range',
                'desc' => 'Price range, e.g. $, $$, $$$ or $$$$',
                'default' => array('gmap_price_range_not_set'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'gmap_price_range_all' => __( 'All', 'wp-sukellos-fw' ),
                    'gmap_price_range_1' => '$',
                    'gmap_price_range_2' => '$$',
                    'gmap_price_range_3' => '$$$',
                    'gmap_price_range_4' => '$$$$',
                ),
                'multiple' => false, // Set to true to use advanced multiple selection
            )
        );
        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_reviews_count_lte',
                'name' => __( 'Gmap reviews count less or equal than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap reviews count less or equal than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_reviews_count_lt',
                'name' => __( 'Gmap reviews count less than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap reviews count less than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_reviews_count_gte',
                'name' => __( 'Gmap reviews count greater or equals than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap reviews count greater or equals than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_reviews_count_gt',
                'name' => __( 'Gmap reviews count greater than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap reviews count greater than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_reviews_rating_lte',
                'name' => __( 'Gmap reviews rating less or equal than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap reviews rating less or equal than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_reviews_rating_lt',
                'name' => __( 'Gmap reviews rating less than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap reviews rating less than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_reviews_rating_gte',
                'name' => __( 'Gmap reviews rating greater or equals than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap reviews rating greater or equals than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_reviews_rating_gt',
                'name' => __( 'Gmap reviews rating greater than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap reviews rating greater than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_photos_count_lte',
                'name' => __( 'Gmap photos count less or equal than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap photos count less or equal than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_photos_count_lt',
                'name' => __( 'Gmap photos count less than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap photos count less than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_photos_count_gte',
                'name' => __( 'Gmap photos count greater or equals than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap photos count greater or equals than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::TEXT,
                'id'   => $options_suffix_param.'_gmap_photos_count_gt',
                'name' => __( 'Gmap photos count greater than', 'wp-sukellos-fw' ),
                'desc' => __( 'Gmap photos count greater than. This is an integer field.', 'wp-sukellos-fw' ),
            )
        );


        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_gmap_is_claimed',
                'name' => 'Gmap is claimed',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('gmap_is_claimed_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'gmap_is_claimed_all' => __( 'All', 'wp-sukellos-fw' ),
                    'gmap_is_claimed_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'gmap_is_claimed_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_title',
                'name' => 'Website has title',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_title_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_title_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_title_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_title_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_meta_keywords',
                'name' => 'Website has meta keywords',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_meta_keywords_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_meta_keywords_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_meta_keywords_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_meta_keywords_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_meta_description',
                'name' => 'Website has meta description',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_meta_description_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_meta_description_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_meta_description_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_meta_description_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_contact_pages',
                'name' => 'Website has contact pages',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_contact_pages_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_contact_pages_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_contact_pages_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_contact_pages_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_emails',
                'name' => 'Website has emails',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_emails_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_emails_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_emails_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_emails_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_phones',
                'name' => 'Website has phones',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_phones_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_phones_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_phones_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_phones_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_facebook',
                'name' => 'Website has Facebook',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_facebook_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_facebook_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_facebook_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_facebook_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_youtube',
                'name' => 'Website has YouTube',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_youtube_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_youtube_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_youtube_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_youtube_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_twitter',
                'name' => 'Website has Twitter',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_twitter_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_twitter_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_twitter_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_twitter_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_instagram',
                'name' => 'Website has Instagram',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_instagram_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_instagram_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_instagram_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_instagram_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_linkedin',
                'name' => 'Website has LinkedIn',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_linkedin_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_linkedin_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_linkedin_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_linkedin_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );

        $gmap_search_tab->create_option(
            array(
                'type' => Item_type::SELECT,
                // Common
                'id' => $options_suffix_param.'_website_has_ad_pixels',
                'name' => 'Website has ad pixels',
                'desc' => 'Boolean (0 = false / 1 = true). Keep All if no filter applied.',
                'default' => array('website_has_ad_pixels_all'),
                'hidden' => false,
                // Specific
                'options' => array(
                    'website_has_ad_pixels_all' => __( 'All', 'wp-sukellos-fw' ),
                    'website_has_ad_pixels_1' => __( 'Yes', 'wp-sukellos-fw' ),
                    'website_has_ad_pixels_0' => __( 'No', 'wp-sukellos-fw' ),
                ),
                'multiple' => false,
            )
        );


        // Debug mode
        $debug_tab = $admin_page->create_tab(
            array(
                'name' => 'Mode DEBUG'
            )
        );

        $debug_tab->create_header(
            array(
                'id' => $options_suffix_param.'_header_debug_mode',
                'name' => __( 'Debug mode', 'wp-sukellos-fw' ),
                'desc' => __( 'DEBUG mode and connectivity test to Scrap.io', 'wp-sukellos-fw' ),
            )
        );

        $debug_tab->create_option(
            array(
                'type' => Item_type::ENABLE,
                'id'      => $options_suffix_param.'_enable_debug',
                'name'    => __( 'Activate the DEBUG mode', 'wp-sukellos-fw' ),
                'desc'    => __( 'Enable/Disable debug remote method test mode', 'wp-sukellos-fw' ),
                'default' => false
            )
        );

    }

}