
    
jQuery(document).ready(function() {

    'use strict';

    /*
     * Private variables.
     */
    var $ = jQuery.noConflict();

    /*
     * Activity fill itself
     */
    $('#sukellos_scrapio_select_activity').select2({
        ajax: {
            url: ajax_object.ajax_url,
            dataType: 'json',
            delay: 250,
            data: function (params) {
                return {
                    action: 'sukellos_scrapio_select_activity', // Nom de l'action à utiliser dans WordPress
                    q: params.term // search term
                };
            },
            processResults: function (data) {
                return {
                    results: data.data.results
                };
            },
            cache: true
        },
        minimumInputLength: 1
    });

    /*
     * Country fill level 1 division
     */
    $('#sukellos_scrapio_select_country').select2({

        width: 'resolve'
    });
    $('#sukellos_scrapio_select_country').on('change', function() {

        var country_code = $(this).val();
        $('#sukellos_scrapio_select_level1_division').val(null).trigger('change'); // Reset region select
        $('#sukellos_scrapio_select_level2_division').val(null).trigger('change'); // Reset department select
        $('#sukellos_scrapio_select_city').val(null).trigger('change'); // Reset city select

        if(country_code) {
            $.ajax({
                url: ajax_object.ajax_url,
                type: 'POST',
                data: {
                    action: 'sukellos_scrapio_select_locations',
                    country: country_code,
                    type: 'admin1',
                },
                success: function(data) {

                    var options = '<option value="">Select level 1 division</option>';

                    data.data.results.forEach(function(admin1) {
                        options += '<option value="' + admin1.id + '">' + admin1.text + '</option>';
                    });
                    $('#sukellos_scrapio_select_level1_division').html(options).trigger('change');
                }
            });
        } else {
            $('#sukellos_scrapio_select_level1_division').html('<option value="">Select level 1 division</option>').trigger('change');
        }
    });

    /*
     * Level 1 division fill level 2 division
     */
    $('#sukellos_scrapio_select_level1_division').select2({

        width: 'resolve'
    });
    $('#sukellos_scrapio_select_level1_division').on('change', function() {

        var country_code = $('#sukellos_scrapio_select_country').val();
        var admin1_code = $(this).val();
        $('#sukellos_scrapio_select_level2_division').val(null).trigger('change'); // Reset department select
        $('#sukellos_scrapio_select_city').val(null).trigger('change'); // Reset city select

        if(admin1_code) {
            $.ajax({
                url: ajax_object.ajax_url,
                type: 'POST',
                data: {
                    action: 'sukellos_scrapio_select_locations',
                    country: country_code,
                    admin1: admin1_code,
                    type: 'admin2',
                },
                success: function(data) {

                    var options = '<option value="">Select level 2 division</option>';

                    data.data.results.forEach(function(admin1) {
                        options += '<option value="' + admin1.id + '">' + admin1.text + '</option>';
                    });
                    $('#sukellos_scrapio_select_level2_division').html(options).trigger('change');
                }
            });
        } else {
            $('#sukellos_scrapio_select_level2_division').html('<option value="">Select level 2 division</option>').trigger('change');
        }
    });


    /*
     * Level 2 division fill city
     */
    $('#sukellos_scrapio_select_level2_division').select2({

        width: 'resolve'
    });
    $('#sukellos_scrapio_select_level2_division').on('change', function() {

        var country_code = $('#sukellos_scrapio_select_country').val();
        var admin1_code = $('#sukellos_scrapio_select_level1_division').val();
        var admin2_code = $(this).val();
        $('#sukellos_scrapio_select_city').val(null).trigger('change'); // Reset city select

        if(admin2_code) {
            $.ajax({
                url: ajax_object.ajax_url,
                type: 'POST',
                data: {
                    action: 'sukellos_scrapio_select_locations',
                    country: country_code,
                    admin1: admin1_code,
                    admin2: admin2_code,
                    type: 'city',
                },
                success: function(data) {

                    var options = '<option value="">Select city</option>';

                    data.data.results.forEach(function(admin1) {
                        options += '<option value="' + admin1.id + '">' + admin1.text + '</option>';
                    });
                    $('#sukellos_scrapio_select_city').html(options).trigger('change');
                }
            });
        } else {
            $('#sukellos_scrapio_select_city').html('<option value="">Select city</option>').trigger('change');
        }
    });

    /*
     * City is simple
     */
    $('#sukellos_scrapio_select_city').select2({

        width: 'resolve'
    });

    /*
     * Event handler for the Import button
     */
    $('#sukellos_scrapio_gmap_search').on('click', function(e) {
        e.preventDefault();

        var activity_type = $('#sukellos_scrapio_select_activity').val();
        var country_code = $('#sukellos_scrapio_select_country').val();
        var admin1_code = $('#sukellos_scrapio_select_level1_division').val();
        var admin2_code = $('#sukellos_scrapio_select_level2_division').val();
        var city = $('#sukellos_scrapio_select_city').val();

        var data = {
            action: 'sukellos_scrapio_gmap_search',
            type: activity_type,
            country: country_code,
        };
        if (admin1_code) {
            data.admin1 = admin1_code;
        }
        if (admin2_code) {
            data.admin2 = admin2_code;
        }
        if (city) {
            data.city = city;
        }

        $.ajax({
            url: ajax_object.ajax_url,
            type: 'POST',
            data: data,
            success: function(response) {
                $("#sukellos_scrapio_import_result").html(response.data);
            },
            error: function(response) {
                $("#sukellos_scrapio_import_result").html(response);
            }
        });
    });

    console.log('Select Activity JS init');
});