<?php

namespace Sukellos;

use Sukellos\Dao\WP_Scrapio_Gmap_Search_Dao;
use Sukellos\ScrapioAPI\WP_Scrapio_API;
use Sukellos\ScrapioAPI\WP_Scrapio_API_Gmap_Search_Param;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\AdminBuilder\Item_Type;
use Sukellos\WPFw\Singleton;
use Sukellos\WPFw\Utils\WP_Log;
use Exception;

defined( 'ABSPATH' ) or exit;

/**
 * Scrap.io requester
 *
 * @since 1.0.0
 */
class WP_Scrapio_Importer {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {
    }

    /**
     * Execute gmap search for next cursor
     *
     * @return void
     */
    public function execute_gmap_search() {

        // Check if a In progress search is in DB
        $results = WP_Scrapio_Gmap_Search_Dao::instance()->get_in_progress_gmap_search();
        WP_Log::debug( __METHOD__, ['$results'=>$results], 'wp-sukellos-fw' );
        $result = $results[0];

        // Rebuild arguments
        $query_id = $result['query_id'];
        $arguments = json_decode( $result['arguments'], true );
        $total_imported = $result['total_imported'];

        // Search next page
        $next_cursor = $result['next_cursor'];

        if ( !is_null( $next_cursor ) ) $arguments[WP_Scrapio_API_Gmap_Search_Param::CURSOR] = $next_cursor;

        // Request Scrap.io
        WP_Log::debug( __METHOD__, ['$arguments'=>$arguments], 'wp-sukellos-fw' );
        $wp_scrapio_search = WP_Scrapio_API::instance()->gmap_search( $arguments, false );

        // Update DB with results
        $next_cursor = null;
        $json_data = $wp_scrapio_search->get_data();
        $total_imported += sizeof( $json_data );
        $status = WP_Scrapio_Gmap_Search_Dao::GMAP_SEARCH_STATUS_IN_PROGRESS;

        WP_Log::debug( __METHOD__, ['$results'=>$results], 'wp-sukellos-fw' );

        if ( $wp_scrapio_search->has_more_pages() ) $next_cursor = $wp_scrapio_search->get_next_cursor();
        else {

            $status = WP_Scrapio_Gmap_Search_Dao::GMAP_SEARCH_STATUS_COMPLETED;

            // Cancel scheduling
            WP_Scrapio_Scheduler::instance()->unschedule_gmap_search();
        }

        WP_Scrapio_Gmap_Search_Dao::instance()->update_gmap_search( $query_id, $total_imported, $next_cursor, $status );
        WP_Scrapio_Gmap_Search_Dao::instance()->replace_gmap_entities( $query_id, $arguments[WP_Scrapio_API_Gmap_Search_Param::TYPE], $json_data );
    }

    /**
     * Request a gmag searh.
     *
     * Will adjust the request using Gmap search parameters from settings page
     *
     * @param $country
     * @param $type
     * @param $admin1
     * @param $admin2
     * @param $city
     * @return void
     */
    public function schedule_gmap_search( $country, $type, $admin1=null, $admin2=null, $city=null ) {

        WP_Log::debug( __METHOD__, ['country'=>$country, 'type'=>$type, 'POST'=>$_POST], 'wp-sukellos-fw' );
        $options_suffix_param = WP_Sukellos_Scrapio_Loader::instance()->get_options_suffix_param();


        if ( is_null( $type ) || empty( $type ) ) {

            throw new WP_Scrapio_Exception( WP_Scrapio_Exception::ERROR_MESSAGES[WP_Scrapio_Exception::GMAP_SEARCH_MISSING_TYPE], WP_Scrapio_Exception::ERROR_CODES[WP_Scrapio_Exception::GMAP_SEARCH_MISSING_TYPE] );
        }
        if ( is_null( $country ) || empty( $country ) ) {

            throw new WP_Scrapio_Exception( WP_Scrapio_Exception::ERROR_MESSAGES[WP_Scrapio_Exception::GMAP_SEARCH_MISSING_COUNTRY_CODE], WP_Scrapio_Exception::ERROR_CODES[WP_Scrapio_Exception::GMAP_SEARCH_MISSING_COUNTRY_CODE] );
        }

        //
        // Build arguments
        //
        $args = array(
            WP_Scrapio_API_Gmap_Search_Param::COUNTRY_CODE => $_POST['country'],
            WP_Scrapio_API_Gmap_Search_Param::TYPE => $_POST['type'],
        );
        if ( isset( $_POST['admin1'] ) ) $args[ WP_Scrapio_API_Gmap_Search_Param::ADMIN1_CODE ] = $_POST['admin1'];
        if ( isset( $_POST['admin2'] ) ) $args[ WP_Scrapio_API_Gmap_Search_Param::ADMIN2_CODE ] = $_POST['admin2'];
        if ( isset( $_POST['city'] ) ) $args[ WP_Scrapio_API_Gmap_Search_Param::CITY ] = $_POST['city'];

        // Parameters from gmap search parameters admin page
        $per_page_list = Admin_Builder::get_option( $options_suffix_param.'_per_page', Item_Type::SELECT );
        $skip_data = Admin_Builder::get_option($options_suffix_param.'_skip_data', Item_type::ENABLE);
        $cursor = Admin_Builder::get_option($options_suffix_param.'_cursor', Item_type::TEXT);
        $gmap_is_main_type_list = Admin_Builder::get_option($options_suffix_param.'_gmap_is_main_type', Item_type::SELECT);
        $gmap_is_closed_list = Admin_Builder::get_option($options_suffix_param.'_gmap_is_closed', Item_type::SELECT);
        $gmap_has_website_list = Admin_Builder::get_option($options_suffix_param.'_gmap_has_website', Item_type::SELECT);
        $gmap_has_phone_list = Admin_Builder::get_option($options_suffix_param.'_gmap_has_phone', Item_type::SELECT);
        $gmap_price_range_list = Admin_Builder::get_option($options_suffix_param.'_gmap_price_range', Item_type::SELECT);
        $gmap_reviews_count_lte = Admin_Builder::get_option($options_suffix_param.'_gmap_reviews_count_lte', Item_type::TEXT);
        $gmap_reviews_count_lt = Admin_Builder::get_option($options_suffix_param.'_gmap_reviews_count_lt', Item_type::TEXT);
        $gmap_reviews_count_gte = Admin_Builder::get_option($options_suffix_param.'_gmap_reviews_count_gte', Item_type::TEXT);
        $gmap_reviews_count_gt = Admin_Builder::get_option($options_suffix_param.'_gmap_reviews_count_gt', Item_type::TEXT);
        $gmap_reviews_rating_lte = Admin_Builder::get_option($options_suffix_param.'_gmap_reviews_rating_lte', Item_type::TEXT);
        $gmap_reviews_rating_lt = Admin_Builder::get_option($options_suffix_param.'_gmap_reviews_rating_lt', Item_type::TEXT);
        $gmap_reviews_rating_gte = Admin_Builder::get_option($options_suffix_param.'_gmap_reviews_rating_gte', Item_type::TEXT);
        $gmap_reviews_rating_gt = Admin_Builder::get_option($options_suffix_param.'_gmap_reviews_rating_gt', Item_type::TEXT);
        $gmap_photos_count_lte = Admin_Builder::get_option($options_suffix_param.'_gmap_photos_count_lte', Item_type::TEXT);
        $gmap_photos_count_lt = Admin_Builder::get_option($options_suffix_param.'_gmap_photos_count_lt', Item_type::TEXT);
        $gmap_photos_count_gte = Admin_Builder::get_option($options_suffix_param.'_gmap_photos_count_gte', Item_type::TEXT);
        $gmap_photos_count_gt = Admin_Builder::get_option($options_suffix_param.'_gmap_photos_count_gt', Item_type::TEXT);
        $gmap_is_claimed_list = Admin_Builder::get_option($options_suffix_param.'_gmap_is_claimed', Item_type::SELECT);
        $website_has_title_list = Admin_Builder::get_option($options_suffix_param.'_website_has_title', Item_type::SELECT);
        $website_has_meta_keywords_list = Admin_Builder::get_option($options_suffix_param.'_website_has_meta_keywords', Item_type::SELECT);
        $website_has_meta_description_list = Admin_Builder::get_option($options_suffix_param.'_website_has_meta_description', Item_type::SELECT);
        $website_has_contact_pages_list = Admin_Builder::get_option($options_suffix_param.'_website_has_contact_pages', Item_type::SELECT);
        $website_has_emails_list = Admin_Builder::get_option($options_suffix_param.'_website_has_emails', Item_type::SELECT);
        $website_has_phones_list = Admin_Builder::get_option($options_suffix_param.'_website_has_phones', Item_type::SELECT);
        $website_has_facebook_list = Admin_Builder::get_option($options_suffix_param.'_website_has_facebook', Item_type::SELECT);
        $website_has_youtube_list = Admin_Builder::get_option($options_suffix_param.'_website_has_youtube', Item_type::SELECT);
        $website_has_twitter_list = Admin_Builder::get_option($options_suffix_param.'_website_has_twitter', Item_type::SELECT);
        $website_has_instagram_list = Admin_Builder::get_option($options_suffix_param.'_website_has_instagram', Item_type::SELECT);
        $website_has_linkedin_list = Admin_Builder::get_option($options_suffix_param.'_website_has_linkedin', Item_type::SELECT);
        $website_has_ad_pixels_list = Admin_Builder::get_option($options_suffix_param.'_website_has_ad_pixels', Item_type::SELECT);

        // Get first from all SELECT fields
        $per_page = $per_page_list[0];
        $gmap_is_main_type = $gmap_is_main_type_list[0];
        $gmap_is_closed = $gmap_is_closed_list[0];
        $gmap_has_website = $gmap_has_website_list[0];
        $gmap_has_phone = $gmap_has_phone_list[0];
        $gmap_price_range = $gmap_price_range_list[0];
        $gmap_is_claimed = $gmap_is_claimed_list[0];
        $website_has_title = $website_has_title_list[0];
        $website_has_meta_keywords = $website_has_meta_keywords_list[0];
        $website_has_meta_description = $website_has_meta_description_list[0];
        $website_has_contact_pages = $website_has_contact_pages_list[0];
        $website_has_emails = $website_has_emails_list[0];
        $website_has_phones = $website_has_phones_list[0];
        $website_has_facebook = $website_has_facebook_list[0];
        $website_has_youtube = $website_has_youtube_list[0];
        $website_has_twitter = $website_has_twitter_list[0];
        $website_has_instagram = $website_has_instagram_list[0];
        $website_has_linkedin = $website_has_linkedin_list[0];
        $website_has_ad_pixels = $website_has_ad_pixels_list[0];

        WP_Log::debug(__METHOD__, [
            'per_page' => $per_page,
            'skip_data' => $skip_data,
            'cursor' => $cursor,
            'gmap_is_main_type' => $gmap_is_main_type,
            'gmap_is_closed' => $gmap_is_closed,
            'gmap_has_website' => $gmap_has_website,
            'gmap_has_phone' => $gmap_has_phone,
            'gmap_price_range' => $gmap_price_range,
            'gmap_reviews_count_lte' => $gmap_reviews_count_lte,
            'gmap_reviews_count_lt' => $gmap_reviews_count_lt,
            'gmap_reviews_count_gte' => $gmap_reviews_count_gte,
            'gmap_reviews_count_gt' => $gmap_reviews_count_gt,
            'gmap_reviews_rating_lte' => $gmap_reviews_rating_lte,
            'gmap_reviews_rating_lt' => $gmap_reviews_rating_lt,
            'gmap_reviews_rating_gte' => $gmap_reviews_rating_gte,
            'gmap_reviews_rating_gt' => $gmap_reviews_rating_gt,
            'gmap_photos_count_lte' => $gmap_photos_count_lte,
            'gmap_photos_count_lt' => $gmap_photos_count_lt,
            'gmap_photos_count_gte' => $gmap_photos_count_gte,
            'gmap_photos_count_gt' => $gmap_photos_count_gt,
            'gmap_is_claimed' => $gmap_is_claimed,
            'website_has_title' => $website_has_title,
            'website_has_meta_keywords' => $website_has_meta_keywords,
            'website_has_meta_description' => $website_has_meta_description,
            'website_has_contact_pages' => $website_has_contact_pages,
            'website_has_emails' => $website_has_emails,
            'website_has_phones' => $website_has_phones,
            'website_has_facebook' => $website_has_facebook,
            'website_has_youtube' => $website_has_youtube,
            'website_has_twitter' => $website_has_twitter,
            'website_has_instagram' => $website_has_instagram,
            'website_has_linkedin' => $website_has_linkedin,
            'website_has_ad_pixels' => $website_has_ad_pixels,
        ], 'wp-sukellos-fw');

        switch( $per_page ) {
            default:
            case 'per_page_all':
                $per_page = 10;
                break;
            case 'per_page_1':
                $per_page = 1;
                break;
            case 'per_page_10':
                $per_page = 10;
                break;
            case 'per_page_25':
                $per_page = 25;
                break;
            case 'per_page_50':
                $per_page = 50;
                break;
        }
        $args[WP_Scrapio_API_Gmap_Search_Param::PER_PAGE] = $per_page;


        if ( $cursor == '' ) $cursor = null;
        else $args[ WP_Scrapio_API_Gmap_Search_Param::CURSOR ] = $cursor;

        if ( $gmap_price_range != 'gmap_price_range_all' ) {
            $args[ WP_Scrapio_API_Gmap_Search_Param::GMAP_PRICE_RANGE ] = $gmap_price_range;
        }

        // Conditions for TEXT
        if (!empty($gmap_reviews_count_lte) && filter_var($gmap_reviews_count_lte, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_REVIEWS_COUNT_LTE] = $gmap_reviews_count_lte;
        }

        if (!empty($gmap_reviews_count_lt) && filter_var($gmap_reviews_count_lt, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_REVIEWS_COUNT_LT] = $gmap_reviews_count_lt;
        }

        if (!empty($gmap_reviews_count_gte) && filter_var($gmap_reviews_count_gte, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_REVIEWS_COUNT_GTE] = $gmap_reviews_count_gte;
        }

        if (!empty($gmap_reviews_count_gt) && filter_var($gmap_reviews_count_gt, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_REVIEWS_COUNT_GT] = $gmap_reviews_count_gt;
        }

        if (!empty($gmap_reviews_rating_lte) && filter_var($gmap_reviews_rating_lte, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_REVIEWS_RATING_LTE] = $gmap_reviews_rating_lte;
        }

        if (!empty($gmap_reviews_rating_lt) && filter_var($gmap_reviews_rating_lt, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_REVIEWS_RATING_LT] = $gmap_reviews_rating_lt;
        }

        if (!empty($gmap_reviews_rating_gte) && filter_var($gmap_reviews_rating_gte, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_REVIEWS_RATING_GTE] = $gmap_reviews_rating_gte;
        }

        if (!empty($gmap_reviews_rating_gt) && filter_var($gmap_reviews_rating_gt, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_REVIEWS_RATING_GT] = $gmap_reviews_rating_gt;
        }

        if (!empty($gmap_photos_count_lte) && filter_var($gmap_photos_count_lte, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_PHOTOS_COUNT_LTE] = $gmap_photos_count_lte;
        }

        if (!empty($gmap_photos_count_lt) && filter_var($gmap_photos_count_lt, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_PHOTOS_COUNT_LT] = $gmap_photos_count_lt;
        }

        if (!empty($gmap_photos_count_gte) && filter_var($gmap_photos_count_gte, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_PHOTOS_COUNT_GTE] = $gmap_photos_count_gte;
        }

        if (!empty($gmap_photos_count_gt) && filter_var($gmap_photos_count_gt, FILTER_VALIDATE_INT) !== false) {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_PHOTOS_COUNT_GT] = $gmap_photos_count_gt;
        }

        // Conditions for SELECT (Boolean)
        if ($gmap_is_main_type != 'gmap_is_main_type_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_IS_MAIN_TYPE] = (int) substr($gmap_is_main_type, -1);
        }

        if ($gmap_is_closed != 'gmap_is_closed_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_IS_CLOSED] = (int) substr($gmap_is_closed, -1);
        }

        if ($gmap_has_website != 'gmap_has_website_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_HAS_WEBSITE] = (int) substr($gmap_has_website, -1);
        }

        if ($gmap_has_phone != 'gmap_has_phone_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_HAS_PHONE] = (int) substr($gmap_has_phone, -1);
        }

        if ($gmap_is_claimed != 'gmap_is_claimed_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::GMAP_IS_CLAIMED] = (int) substr($gmap_is_claimed, -1);
        }

        if ($website_has_title != 'website_has_title_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_TITLE] = (int) substr($website_has_title, -1);
        }

        if ($website_has_meta_keywords != 'website_has_meta_keywords_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_META_KEYWORDS] = (int) substr($website_has_meta_keywords, -1);
        }

        if ($website_has_meta_description != 'website_has_meta_description_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_META_DESCRIPTION] = (int) substr($website_has_meta_description, -1);
        }

        if ($website_has_contact_pages != 'website_has_contact_pages_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_CONTACT_PAGES] = (int) substr($website_has_contact_pages, -1);
        }

        if ($website_has_emails != 'website_has_emails_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_EMAILS] = (int) substr($website_has_emails, -1);
        }

        if ($website_has_phones != 'website_has_phones_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_PHONES] = (int) substr($website_has_phones, -1);
        }

        if ($website_has_facebook != 'website_has_facebook_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_FACEBOOK] = (int) substr($website_has_facebook, -1);
        }

        if ($website_has_youtube != 'website_has_youtube_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_YOUTUBE] = (int) substr($website_has_youtube, -1);
        }

        if ($website_has_twitter != 'website_has_twitter_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_TWITTER] = (int) substr($website_has_twitter, -1);
        }

        if ($website_has_instagram != 'website_has_instagram_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_INSTAGRAM] = (int) substr($website_has_instagram, -1);
        }

        if ($website_has_linkedin != 'website_has_linkedin_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_LINKEDIN] = (int) substr($website_has_linkedin, -1);
        }

        if ($website_has_ad_pixels != 'website_has_ad_pixels_all') {
            $args[WP_Scrapio_API_Gmap_Search_Param::WEBSITE_HAS_AD_PIXELS] = (int) substr($website_has_ad_pixels, -1);
        }

        if ($skip_data) $args[WP_Scrapio_API_Gmap_Search_Param::SKIP_DATA] = 1;
        else $args[WP_Scrapio_API_Gmap_Search_Param::SKIP_DATA] = 0;

        WP_Log::debug(__METHOD__.' - Ready for gmap/search', ['args'=>$args], 'wp-sukellos-fw');

        // Request without data to get at least total count
        $args[WP_Scrapio_API_Gmap_Search_Param::SKIP_DATA] = 1;

        // Request Scrap.io
        $wp_scrapio_search = WP_Scrapio_API::instance()->gmap_search( $args, false );
        $count = $wp_scrapio_search->get_count();

        if (!$skip_data && ( $count > 0 ) ) {

            $args[WP_Scrapio_API_Gmap_Search_Param::SKIP_DATA] = 0;

            // Check if no request already started
            $results = WP_Scrapio_Gmap_Search_Dao::instance()->get_in_progress_gmap_search();
            if ( !empty( $results ) ) {

                throw new WP_Scrapio_Exception( WP_Scrapio_Exception::ERROR_MESSAGES[WP_Scrapio_Exception::GMAP_SEARCH_ALREADY_NI_PROGRESS], WP_Scrapio_Exception::ERROR_CODES[WP_Scrapio_Exception::GMAP_SEARCH_ALREADY_NI_PROGRESS] );
            }

            // Check if cache is activated and already imported data
            $gmap_in_cache = WP_Scrapio_Cacher::instance()->gmap_search_in_cache( $args );
            if ( $gmap_in_cache ) {

                throw new WP_Scrapio_Exception( WP_Scrapio_Exception::ERROR_MESSAGES[WP_Scrapio_Exception::GMAP_SEARCH_IN_CACHE], WP_Scrapio_Exception::ERROR_CODES[WP_Scrapio_Exception::GMAP_SEARCH_IN_CACHE] );
            }

            // Insert query
            $query_id = WP_Scrapio_Gmap_Search_Dao::instance()->insert_gmap_search( $type, $country, $admin1, $admin2, $city, $args, $wp_scrapio_search->get_count(), $per_page, $cursor );

            // Schedule action
            WP_Scrapio_Scheduler::instance()->schedule_gmap_search();

            return true;
        }

        // Schedule only if Skip data is false
        return $wp_scrapio_search;
    }
}
