<?php

namespace Sukellos;

use Sukellos\Dao\WP_Scrapio_Gmap_Search_Dao;
use Sukellos\ScrapioAPI\WP_Scrapio_API;
use Sukellos\ScrapioAPI\WP_Scrapio_API_Gmap_Search_Param;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\AdminBuilder\Item_Type;
use Sukellos\WPFw\Singleton;
use Sukellos\WPFw\Utils\WP_Log;
use Exception;

defined( 'ABSPATH' ) or exit;

/**
 * Scrap.io requester
 *
 * @since 1.0.0
 */
class WP_Scrapio_Scheduler {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {

        // Add schedules
        add_filter('cron_schedules', array( $this, 'filter_cron_schedules' ), 10, 1 );

        // Force adding a wp hook to check if a search may be performed
        add_action( 'wp', array( $this, 'action_wp' ) );
        add_action( 'execute_gmap_search_hook', array( WP_Scrapio_Importer::instance(), 'execute_gmap_search' ) );
    }

    /**
     * Cancel scheduling for execute_gmap_search_hook
     * @return void
     */
    public function unschedule_gmap_search() {

        // Cancel scheduling
        $timestamp = wp_next_scheduled( 'execute_gmap_search_hook' );
        if ( $timestamp ) {

            wp_unschedule_event( $timestamp, 'execute_gmap_search_hook' );
        }
        // To be sure all removing
        wp_clear_scheduled_hook( 'execute_gmap_search_hook' );
    }

    /**
     * May set coherency for scheduling
     * @return void
     */
    public function action_wp() {

        WP_Log::debug( __METHOD__, [], 'wp-sukellos-fw' );

        // Check if a In progress search is in DB
        $results = WP_Scrapio_Gmap_Search_Dao::instance()->get_in_progress_gmap_search();
        WP_Log::debug( __METHOD__, ['$results'=>$results], 'wp-sukellos-fw' );

        $is_scheduled = wp_next_scheduled( 'execute_gmap_search_hook' );
        WP_Log::debug( __METHOD__.' - execute_gmap_search_hook scheduled?', ['$is_scheduled'=>$is_scheduled?'true':'false'], 'wp-sukellos-fw' );

        if ( !$is_scheduled && !empty( $results ) ) {

            $result = $results[ 0 ];
            $query_id = $result[ 'query_id' ];

            // Schedule action
            wp_schedule_event( time(), 'every_minute', 'execute_gmap_search_hook' );
        }
        else if ( $is_scheduled && empty( $results ) ) {

            $this->unschedule_gmap_search();
        }
    }

    /**
     * Add schedules
     * @param $schedules
     * @return mixed
     */
    public function filter_cron_schedules( $schedules ) {

        $schedules['every_minute'] = array(
            'interval' => 60,
            'display' => __('Every Minute', 'wp-sukellos-fw')
        );
        $schedules['every_ten_seconds'] = array(
            'interval' => 10,
            'display' => __('Every 10 seconds', 'wp-sukellos-fw')
        );
        return $schedules;
    }

    /**
     * Add scheduling for gmap search
     */
    public function schedule_gmap_search(  ) {

        // Schedule action
        wp_schedule_event( time(), 'every_minute', 'execute_gmap_search_hook' );
    }
}
