<?php

namespace Sukellos;

use Sukellos\Dao\WP_Scrapio_Gmap_Entities_Dao;
use Sukellos\Dao\WP_Scrapio_Gmap_Search_Dao;
use Sukellos\WPFw\Utils\WP_Log;
use WP_List_Table;

defined( 'ABSPATH' ) or exit;

/**
 * Scrap.io searches list table manager
 *
 * https://developer.wordpress.org/reference/classes/wp_list_table/
 *
 * @since 1.0.0
 */
class WP_Scrapio_Searches_List_Table extends WP_List_Table {

    private $result_message = null;

    public function __construct() {

        parent::__construct( array(
            'singular' => 'scrapio_search',
            'plural' => 'scrapio_searches',
            'ajax' => false
        ) );
    }

    /**
     * Gets a list of columns.
     *
     * This method should be overridden to return an associative array of columns.
     * The associative array should follow the format 'slug' => array( 'Title', true ).
     * Typically, you will use this in the prepare_items() method to build part of the _column_headers property.
     *
     * @return string[]
     */
    public function get_columns() {

        $columns = array(
            'type' => __( 'Type', 'wp-sukellos-fw'),
            'country_code' => __( 'Country code', 'wp-sukellos-fw'),
            'admin1' => __( 'Admin1', 'wp-sukellos-fw'),
            'admin2' => __( 'Admin2', 'wp-sukellos-fw'),
            'city' => __( 'City', 'wp-sukellos-fw'),
            'started_at' => __( 'Started at', 'wp-sukellos-fw'),
            'last_fetched' => __( 'Last fetched', 'wp-sukellos-fw'),
            'total_count' => __( 'Total count', 'wp-sukellos-fw'),
            'total_imported' => __( 'Total imported', 'wp-sukellos-fw'),
            'status' => __( 'Status', 'wp-sukellos-fw'),
        );
        return $columns;
    }

    /**
     * Used to return the column value, from DB structure retrieved from gmap_searches table
     *
     * This is method that is used to render a column when no other specific method exists for that column.
     * When WP_List_Tables attempts to render your columns (within single_row_columns()), it first checks for a column-specific method. If none exists, it defaults to this method instead.
     * This method accepts two arguments, a single $item array and the $column_name (as a slug).
     * @param $item
     * @param $column_name
     * @return bool|mixed|string|void
     */
    public function column_default( $item, $column_name ) {

        switch ( $column_name ) {
            case 'type':
            case 'country_code':
            case 'admin1':
            case 'admin2':
            case 'city':
            case 'started_at':
            case 'last_fetched':
            case 'total_count':
            case 'total_imported':
            case 'status':

                return $item[ $column_name ];
            default:
                return print_r( $item, true );
        }
    }

    /**
     * Gets a list of sortable columns.
     *
     * The format is:
     *  'internal-name' => 'orderby'
     *  'internal-name' => array( 'orderby', bool, 'abbr', 'orderby-text', 'initially-sorted-column-order' ) –
     *  'internal-name' => array( 'orderby', 'asc' ) – The second element sets the initial sorting order.
     *  'internal-name' => array( 'orderby', true ) – The second element makes the initial order descending.
     *
     * In the second format, passing true as second parameter will make the initial sorting order be descending.
     * Following parameters add a short column name to be used as ‘abbr’ attribute, a translatable string for the current sorting, and the initial order for the initial sorted column, ‘asc’ or ‘desc’ (default: false).
     *
     * See https://developer.wordpress.org/reference/classes/wp_list_table/get_sortable_columns/
     *
     * @return array[]
     */
    public function get_sortable_columns() {

        $sortable_columns = array(
            'type' => array( 'type', false ),
            'admin1' => array( 'admin1', false ),
            'admin2' => array( 'admin2', false ),
            'city' => array( 'city', false ),
            'started_at' => array( 'started_at', false ),
            'last_fetched' => array( 'last_fetched', false ),
            'total_count' => array( 'total_count', false ),
            'total_imported' => array( 'total_imported', false ),
            'status' => array( 'status', false ),
        );
        return $sortable_columns;
    }

    /**
     * Displays extra controls between bulk actions and pagination.
     *
     * See https://developer.wordpress.org/reference/classes/wp_list_table/extra_tablenav/
     *
     * @param $which
     * @return void
     */
    public function extra_tablenav( $which ) {

        if ($which == "top") {
            ?>
            <div class="alignleft actions filtre-grille">
                <div class="colonne">
                    <label for="filter-by-type"><?php echo __( 'type', 'wp-sukellos-fw'); ?></label>
                    <input type="text" name="type" id="filter-by-type" value="<?php echo esc_attr(isset($_POST['type']) ? $_POST['type'] : (isset($_SESSION['type_filter']) ? $_SESSION['type_filter'] : '')); ?>" />

                    <label for="filter-by-city"><?php echo __( 'city', 'wp-sukellos-fw'); ?></label>
                    <input type="text" name="type" id="filter-by-city" value="<?php echo esc_attr(isset($_POST['city']) ? $_POST['city'] : (isset($_SESSION['city_filter']) ? $_SESSION['city_filter'] : '')); ?>" />

                    <input type="submit" name="filter_action" id="post-query-submit" class="button" value="<?php echo __( 'Filter', 'wp-sukellos-fw'); ?>">
                </div>

                <div class="colonne">
                    <label for="filter-by-admin1"><?php echo __( 'admin1', 'wp-sukellos-fw'); ?></label>
                    <input type="text" name="type" id="filter-by-admin1" value="<?php echo esc_attr(isset($_POST['admin1']) ? $_POST['admin1'] : (isset($_SESSION['admin1_filter']) ? $_SESSION['admin1_filter'] : '')); ?>" />

                    <label for="filter-by-status"><?php echo __( 'status', 'wp-sukellos-fw'); ?></label>
                    <input type="text" name="status" id="filter-by-status" value="<?php echo esc_attr(isset($_POST['status']) ? $_POST['status'] : (isset($_SESSION['status_filter']) ? $_SESSION['status_filter'] : '')); ?>" />
                </div>

                <div class="colonne">
                    <label for="filter-by-admin2"><?php echo __( 'admin2', 'wp-sukellos-fw'); ?></label>
                    <input type="text" name="admin2" id="filter-by-admin2" value="<?php echo esc_attr(isset($_POST['admin2']) ? $_POST['admin2'] : (isset($_SESSION['admin2_filter']) ? $_SESSION['admin2_filter'] : '')); ?>" />
                </div>
            </div>
            <?php
        }
    }

    /**
     * Prepares the list of items for displaying.
     * Developers should use this class to query and filter data, handle sorting, and pagination, and any other data-manipulation required prior to rendering.
     * This method should be called explicitly after instantiating your class, and before rendering.
     *
     * See https://developer.wordpress.org/reference/classes/wp_list_table/prepare_items/
     *
     * @return void
     */
    public function prepare_items() {

        WP_Log::debug( __METHOD__, ['REQUEST'=>$_REQUEST, 'GET'=>$_GET, 'POST'=>$_POST], 'wp-sukellos-fw' );

        //  $_column_headers
        //      In core, this property is assigned automatically. Developers must manually define it in their prepare_items() or __construct() methods.
        //      This property requires a 4-value array :
        //      - The first value is an array containing column slugs and titles (see the get_columns() method).
        //      - The second value is an array containing the values of fields to be hidden.
        //      - The third value is an array of columns that should allow sorting (see the get_sortable_columns() method).
        //      - The fourth value is a string defining which column is deemed to be the primary one, displaying the row’s actions (edit, view, etc). The value should match that of one of your column slugs in the first value.
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array( $columns, $hidden, $sortable );

        // Tableau des filtres
        $filters = [
            'type' => null,
            'admin1' => null,
            'admin2' => null,
            'city' => null,
            'status' => null,
        ];

        // Traitement des filtres avec session pour chaque filtre
        foreach ($filters as $key => &$filter) {
            if (isset($_POST[$key])) {
                if (!empty($_POST[$key])) {
                    $filter = sanitize_text_field($_POST[$key]);
                    // Stocker dans la session
                    $_SESSION["{$key}_filter"] = $filter;
                } else {
                    // Supprimer de la session si vide
                    unset($_SESSION["{$key}_filter"]);
                }
            } elseif (isset($_SESSION["{$key}_filter"]) && !empty($_SESSION["{$key}_filter"])) {
                // Récupérer la valeur depuis la session si disponible
                $filter = sanitize_text_field($_SESSION["{$key}_filter"]);
            }
        }

        // Extraction des filtres traités pour les utiliser plus tard
        [
            'type' => $type_filter,
            'admin1' => $admin1_filter,
            'admin2' => $admin2_filter,
            'city' => $city_filter,
            'status' => $status_filter
        ] = $filters;

        // Ordering
        $orderby = ( !empty( $_REQUEST[ 'orderby' ] ) ) ? $_REQUEST[ 'orderby' ] : 'query_id';
        $order = ( !empty( $_REQUEST[ 'order' ] ) ) ? $_REQUEST[ 'order' ] : 'DESC';
        $per_page = 200;
        $current_page = $this->get_pagenum();
        $offset = ( $current_page - 1 ) * $per_page;

        // Request data
        $data = WP_Scrapio_Gmap_Search_Dao::instance()->get_searches( $type_filter, $admin1_filter, $admin2_filter, $city_filter, $status_filter, $orderby, $order, $offset, $per_page );
        $total_items = count( $data );

        $data  = array_slice($data, (($current_page-1) * $per_page), $per_page);


        // $_pagination_args
        //      Stores information needed for handling table pagination (as an array). This generally isn’t manipulated directly, but rather used with get_pagination_arg( string ) or set_pagination_args(array).
        $this->set_pagination_args( array(
            'total_items' => $total_items,
            'per_page' => $per_page,
            'total_pages' => ceil( $total_items / $per_page )
        ) );

        $this->items = $data;
    }
}

