<?php

namespace Sukellos\Dao;

use Sukellos\WPFw\Singleton;
use Sukellos\WPFw\Utils\WP_Log;

defined( 'ABSPATH' ) or exit;

/**
 * This class is used to CRUD queries into DB
 *
 * @since 1.0.0
 */
class WP_Scrapio_Gmap_Search_Dao {

    // Use Trait Singleton
    use Singleton;

    const GMAP_SEARCH_STATUS_IN_PROGRESS = 'open';
    const GMAP_SEARCH_STATUS_COMPLETED = 'done';

    /**
     * Search for a query with exact or more wide params.
     * @param $type
     * @param $country_code
     * @param $admin1
     * @param $admin2
     * @param $city
     * @return array|object|\stdClass[]|null
     */
    public function retrieve_gmap_search( $type, $country_code, $admin1=null, $admin2=null, $city=null ) {

        global $wpdb;
        $table_gmap_searches = $wpdb->prefix."scrapio_gmap_searches";

        $params = array();

        // Build SQL
        $sql = "SELECT *
                FROM ".$table_gmap_searches."
                WHERE type='".$type."'
                AND country_code='".$country_code."'";

        // If City is not null,
        //  then: admin1/admin2/city OR admin1/admin2/NULL OR admin1/NULL/NULL OR NULL/NULL/NULL
        if ( !is_null( $city ) ) {

            $sql .= "
             AND 
                ( 
                    ( admin1='".$admin1."' AND admin2='".$admin2."' AND city='".$city."' )
                    OR ( admin1='".$admin1."' AND admin2='".$admin2."' AND ISNULL(city) )
                    OR ( admin1='".$admin1."' AND ISNULL(admin2) AND ISNULL(city) )
                    OR ( ISNULL(admin1) AND ISNULL(admin2) AND ISNULL(city) )             
                )
             ";
        }

        // Else If Admin2 is not null (City is null),
        //  then: admin1/admin2/NULL OR admin1/NULL/NULL OR NULL/NULL/NULL
        else if ( !is_null( $admin2 ) ) {

            $sql .= "
             AND 
                ( 
                    ( admin1='".$admin1."' AND admin2='".$admin2."' AND ISNULL(city) )
                    OR ( admin1='".$admin1."' AND ISNULL(admin2) AND ISNULL(city) )
                    OR ( ISNULL(admin1) AND ISNULL(admin2) AND ISNULL(city) )             
                )
             ";
        }

        // Else If Admin1 is not null (Admin2 and City are null),
        //  then: admin1/NULL/NULL OR NULL/NULL/NULL
        else if ( !is_null( $admin1 ) ) {

            $sql .= "
             AND 
                ( 
                    ( admin1='".$admin1."' AND ISNULL(admin2) AND ISNULL(city) )
                    OR ( ISNULL(admin1) AND ISNULL(admin2) AND ISNULL(city) )             
                )
             ";
        }

        // Else (Admin1 and Admin2 and City are null),
        //  then: NULL/NULL/NULL
        else {

            $sql .= "
             AND ( ISNULL(admin1) AND ISNULL(admin2) AND 'ISNULL(city) )    
             ";
        }

        $prepared_statement = $wpdb->prepare($sql, $params);
        $results = $wpdb->get_results( $prepared_statement, 'ARRAY_A' );
        WP_Log::debug(__METHOD__, ['Result of select'=>$results, 'Statement'=>$prepared_statement], 'wp-sukellos-fw');

        return $results;
    }

    /**
     * Get query in status In progress
     * @return array|object|\stdClass[]|null
     */
    public function get_in_progress_gmap_search() {

        global $wpdb;
        $table_gmap_searches = $wpdb->prefix."scrapio_gmap_searches";

        $params = array();

        // Build SQL
        $sql = "SELECT *
                FROM ".$table_gmap_searches."
                WHERE status='".self::GMAP_SEARCH_STATUS_IN_PROGRESS."'";

        $prepared_statement = $wpdb->prepare($sql, $params);
        $results = $wpdb->get_results( $prepared_statement, 'ARRAY_A' );
        WP_Log::debug(__METHOD__, ['Result of select'=>$results, 'Statement'=>$prepared_statement], 'wp-sukellos-fw');

        return $results;
    }

    /**
     * Insert a Scrap.io Gmap search in status In progress
     * @param $type
     * @param $country_code
     * @param $admin1
     * @param $admin2
     * @param $city
     * @param $args
     * @param $per_page
     * @param $next_cursor
     * @return int
     */
    public function insert_gmap_search( $type, $country_code, $admin1=null, $admin2=null, $city=null, $args, $total_count, $per_page=10, $next_cursor=null ) {

        global $wpdb;
        $table_gmap_searches = $wpdb->prefix."scrapio_gmap_searches";

        // Insert gmap search
        $params_keys = array(
            'type' => $type,
            'country_code' => $country_code,
            'arguments' => json_encode( $args ),
            'total_count' => $total_count,
            'per_page' => $per_page,
            'status' => self::GMAP_SEARCH_STATUS_IN_PROGRESS,
        );
        $params_values = array(
            '%s',
            '%s',
            '%s',
            '%d',
            '%d',
            '%s',
        );
        if ( !is_null( $admin1 ) ) {
            $params_keys['admin1'] = $admin1;
            $params_values[] = '%s';
        }
        if ( !is_null( $admin2 ) ) {
            $params_keys['admin2'] = $admin2;
            $params_values[] = '%s';
        }
        if ( !is_null( $city ) ) {
            $params_keys['city'] = $city;
            $params_values[] = '%s';
        }
        if ( !is_null( $next_cursor ) ) {
            $params_keys['next_cursor'] = $next_cursor;
            $params_values[] = '%s';
        }

        $wpdb->insert(
            $table_gmap_searches,
            $params_keys,
            $params_values
        );
        $query_id = $wpdb->insert_id;

        return $query_id;
    }

    /**
     * Insert the response of a Scrap.io Gmap search
     * @param $type
     * @param $country_code
     * @param $admin1
     * @param $admin2
     * @param $city
     * @param $entities an array containing all Gmap entities (responses)
     * @return int
     */
    public function update_gmap_search( $query_id, $total_imported, $next_cursor=null, $status ) {

        global $wpdb;
        $table_gmap_searches = $wpdb->prefix."scrapio_gmap_searches";

        // Insert gmap search
        $params_keys = array(
            'next_cursor' => is_null($next_cursor) ? 'NULL' : $next_cursor,
            'total_imported' => $total_imported,
            'status' => $status,
            'last_fetched' => current_time('mysql', false),
        );
        $params_where = array(
            'query_id' => $query_id,
        );
        $wpdb->update(
            $table_gmap_searches,
            $params_keys,
            $params_where
        );

        return $query_id;
    }

    /**
     * Insert or update gmap entities
     * @param $query_id
     * @param $json_data json data as an array
     * @return void
     */
    public function replace_gmap_entities( $query_id, $type, $json_data ) {

        global $wpdb;

        // Second insert Gmap entities
        $table_name = $wpdb->prefix."scrapio_gmap_entities";

        $replace_entities_sql = "REPLACE INTO ".$table_name." (query_id,google_id,place_id,name,type,country_code,admin1,admin2,zip,city,entity_json) VALUES ";
        $params = array();
        $placeholders = array();

        // Get all entities
        foreach ( $json_data as $entity ) {

            // Add placeholders
            $placeholders[] = "(%d, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)";

            // Add parameters
            $params[] = $query_id;
            $params[] = $entity->google_id;
            $params[] = $entity->place_id;
            $params[] = $entity->name;
            $params[] = $type;
            $params[] = $entity->location_country_code;
            $params[] = $entity->location_admin1_code;
            $params[] = $entity->location_admin2_code;
            $params[] = $entity->location_postal_code;
            $params[] = $entity->location_city;
            $params[] = json_encode($entity);
        }
        // Combine placeholders into the SQL statement
        $replace_entities_sql .= implode( ', ', $placeholders );

        // Prepare the SQL statement with parameters
        $prepared_query = $wpdb->prepare( $replace_entities_sql, ...$params );

        // Execute the query
        $wpdb->query( $prepared_query );
    }


    /**
     * Get licences using filters
     * @return array|object|\stdClass[]|null
     */
    public function get_searches( $type_filter=null, $admin1_filter=null, $admin2_filter=null, $city_filter=null, $status_filter=null, $orderby='query_id', $order='DESC', $offset=0, $limit=50 ) {

        global $wpdb;
        $table = $wpdb->prefix."scrapio_gmap_searches";

        $params = array();

        // Build SQL
        $sql = "SELECT * FROM ".$table." WHERE 1=1";

        // Add filters
        if ( !is_null( $type_filter ) ) {

            $sql .= " AND type LIKE %s";
            $params[] = '%' . $wpdb->esc_like( $type_filter ) . '%';
        }
        if ( !is_null( $admin1_filter ) ) {

            $sql .= " AND admin1 LIKE %s";
            $params[] = '%' . $wpdb->esc_like( $admin1_filter ) . '%';
        }
        if ( !is_null( $admin2_filter ) ) {

            $sql .= " AND admin2 LIKE %s";
            $params[] = '%' . $wpdb->esc_like( $admin2_filter ) . '%';
        }
        if ( !is_null( $city_filter ) ) {

            $sql .= " AND city LIKE %s";
            $params[] = '%' . $wpdb->esc_like( $city_filter ) . '%';
        }
        if ( !is_null( $status_filter ) ) {

            $sql .= " AND status LIKE %s";
            $params[] = '%' . $wpdb->esc_like( $status_filter ) . '%';
        }

        $sql .= " ORDER BY ". esc_sql($orderby) ." ".(strtolower( $order )=='desc'?"DESC":"ASC");

        if ( !is_null( $limit ) ) {

            $sql .= ' LIMIT %d, %d';
            $params[]=$offset;
            $params[]=$limit;
        }
        WP_Log::debug(__METHOD__, ['SQL'=>$sql], 'ati3d');

        $prepared_statement = $wpdb->prepare($sql, ...$params);
        WP_Log::debug(__METHOD__, ['Statement'=>$prepared_statement], 'ati3d');

        $results = $wpdb->get_results( $prepared_statement, 'ARRAY_A' );
        WP_Log::debug(__METHOD__, ['Results'=>$results], 'ati3d');

        return $results;
    }
}
