<?php

namespace Sukellos;

use Sukellos\WPFw\Utils\WP_Log;

defined( 'ABSPATH' ) or exit;

/**
 * URL_Repeater_Data field Class
 *
 * @since 1.0.0
 */
abstract class URL_Repeater_Data extends Field {

    // "website_data": {
    //		"url": "https://www.cerclesdelaforme.com/salle-de-sport/championnet-18eme",
    //		"lang": "fr",
    //		"title": "Salle de Sport Championnet Paris 18 - Cercles de la Forme",
    //		"domain": "cerclesdelaforme.com",
    //		"emails": [
    //			{
    //				"email": "clientcdf@lescerclesdelaforme.com",
    //				"sources": [
    //					"https://www.cerclesdelaforme.com/salle-de-sport/championnet-18eme/"
    //				]
    //			}
    //		],
    //		"phones": null,
    //		"status": "completed",
    //		"twitter": [
    //			"https://twitter.com/cerclesdelaform"
    //		],
    //		"youtube": [
    //			"https://youtube.com/user/CerclesdelaformeTV"
    //		],
    //		"facebook": [
    //			"https://facebook.com/cerclesdelaforme"
    //		],
    //		"is_empty": null,
    //		"linkedin": null,
    //		"ad_pixels": [
    //			"Google Tag Manager"
    //		],
    //		"instagram": [
    //			"https://instagram.com/cerclesdelaforme",
    //			"https://instagram.com/1896641480634370"
    //		],
    //		"scraped_at": "2024-05-30T11:29:59.000000Z",
    //		"technologies": [
    //			"Google Analytics",
    //			"Google Tag Manager",
    //			"reCAPTCHA",
    //			"Ubuntu",
    //			"WooCommerce",
    //			"WordPress",
    //			"Yoast SEO",
    //			"PHP",
    //			"MySQL"
    //		],
    //		"contact_pages": [
    //			"https://www.cerclesdelaforme.com/contact-ce"
    //		],
    //		"is_responding": true,
    //		"meta_keywords": null,
    //		"meta_og_image": "https://www.cerclesdelaforme.com/wp-content/uploads/circuit-feminin5.jpg",
    //		"meta_og_title": "Salle de Sport Championnet Paris 18 - Cercles de la Forme",
    //		"meta_generator": null,
    //		"meta_description": "Essai Gratuit ✅ Le Cercle Championnet (Paris 18) est une salle de sport à l'ambiance décontractée, apprécié par les habitants de quartier."
    //	},

    /**
     * Get the specific ACF Custom Field definition
     */
    public function get_specific_acf_field_definition() {

        return array(
            'type' => 'repeater',
            'instructions' => '',
            'required' => 0,
            'layout' => 'table',
            'pagination' => 0,
            'min' => 0,
            'max' => 0,
            'collapsed' => '',
            'button_label' => 'Ajouter un élément',
            'rows_per_page' => 20,
            'sub_fields' => array(
                array(
                    'key' => $this->get_acf_field_key().'_'.'url',
                    'label' => 'URL',
                    'name' => $this->get_acf_field_name().'_'.'url',
                    'aria-label' => '',
                    'type' => 'url',
                    'instructions' => '',
                    'required' => 0,
                    'conditional_logic' => 0,
                    'wrapper' => array(
                        'width' => '',
                        'class' => '',
                        'id' => '',
                    ),
                    'default_value' => '',
                    'placeholder' => '',
                    'parent_repeater' => $this->get_acf_field_key(),
                ),
            ),
        );
    }


    /**
     * Insert the field as a WordPress ACF Custom Field
     *
     * MUST be called after set_data()
     *
     * MUST be overriden if the type is complex (other than simple text, url...)
     */
    public function update_acf_field( $post_id ) {

        if ( is_null( $this->data ) ) return false;

        if ( !isset( $this->data['website_data'] ) || is_null( $this->data['website_data'] ) || empty( $this->data['website_data'] )  )  return false;

        // Get its self data from gmap entity JSON data
        $website_data = $this->data['website_data'];
        if ( !isset( $website_data[$this->field_id] ) || is_null( $website_data[$this->field_id] ) || empty( $website_data[$this->field_id] )  )  return false;

        $self_data = $website_data[$this->field_id];
        WP_Log::debug( __METHOD__, ['field_id'=>$this->field_id, '$self_data'=>$self_data], 'wp-sukellos-fw' );

        // Build repeater
        $repeater = array();
        foreach ( $self_data as $c_data ) {

            $repeater[] = array( $this->get_acf_field_key().'_'.'url' => $c_data );
        }

        update_field( $this->get_acf_field_name(), $repeater, $post_id );
    }
}
