<?php

namespace Sukellos;

use Sukellos\WPFw\Utils\WP_Log;

defined( 'ABSPATH' ) or exit;

/**
 * Emails field Class
 *
 * @since 1.0.0
 */
class Emails extends Field {

    // "website_data": {
    //		...
    //		"emails": [
    //			{
    //				"email": "name@emailaddress.com",
    //				"sources": [
    //					"https://linkr.bio/cpapoternedespeupliers"
    //				]
    //			},
    //			{
    //				"email": "poternedespeupliers@ligueparis.org",
    //				"sources": [
    //					"https://linkr.bio/cpapoternedespeupliers"
    //				]
    //			}
    //		],

    protected $field_id = 'emails';
    protected $field_label = 'Emails';

    /**
     * Get the specific ACF Custom Field definition
     */
    public function get_specific_acf_field_definition() {

        return array(
            'type' => 'repeater',
            'instructions' => '',
            'required' => 0,
            'layout' => 'table',
            'pagination' => 0,
            'min' => 0,
            'max' => 0,
            'collapsed' => '',
            'button_label' => 'Ajouter un élément',
            'rows_per_page' => 20,
            'sub_fields' => array(
                array(
                    'key' => $this->get_acf_field_key().'_'.'email',
                    'label' => 'Email',
                    'name' => $this->get_acf_field_name().'_'.'email',
                    'aria-label' => '',
                    'type' => 'email',
                    'instructions' => '',
                    'required' => 0,
                    'conditional_logic' => 0,
                    'wrapper' => array(
                        'width' => '',
                        'class' => '',
                        'id' => '',
                    ),
                    'default_value' => '',
                    'placeholder' => '',
                    'parent_repeater' => $this->get_acf_field_key(),
                ),
            ),
        );
    }

    /**
     * Insert the field as a WordPress ACF Custom Field
     *
     * MUST be called after set_data()
     *
     * MUST be overriden if the type is complex (other than simple text, url...)
     */
    public function update_acf_field( $post_id ) {

        if ( is_null( $this->data ) ) return false;

        if ( !isset( $this->data['website_data'] ) || is_null( $this->data['website_data'] ) || empty( $this->data['website_data'] )  )  return false;

        // Get its self data from gmap entity JSON data
        $website_data = $this->data['website_data'];
        if ( !isset( $website_data[$this->field_id] ) || is_null( $website_data[$this->field_id] ) || empty( $website_data[$this->field_id] )  )  return false;

        $self_data = $website_data[$this->field_id];
        WP_Log::debug( __METHOD__, ['field_id'=>$this->field_id, '$self_data'=>$self_data], 'wp-sukellos-fw' );

        // Build repeater
        $repeater = array();
        foreach ( $self_data as $c_data ) {

            $repeater[] = array( $this->get_acf_field_key().'_'.'email' => $c_data['email'] );
        }

        update_field( $this->get_acf_field_name(), $repeater, $post_id );
    }
}
