<?php

namespace Sukellos;

use Sukellos\WPFw\Utils\WP_Log;

defined( 'ABSPATH' ) or exit;

/**
 * Location field Class
 *
 * @since 1.0.0
 */
class Location extends Field {

    // "location_latitude": "48.8206464",
    // "location_longitude": "2.3512259",
    protected $field_id = 'location';
    protected $field_label = 'Location';

    /**
     * Get the specific ACF Custom Field definition
     */
    public function get_specific_acf_field_definition() {

        return array(
            'type' => 'google_map',
            'instructions' => '',
            'required' => 0,
            'center_lat' => '',
            'center_lng' => '',
            'zoom' => '',
            'height' => '',
        );
    }

    /**
     * Insert the field as a WordPress ACF Custom Field
     *
     * MUST be called after set_data()
     *
     * MUST be overriden if the type is complex (other than simple text, url...)
     */
    public function update_acf_field( $post_id ) {

        if ( is_null( $this->data ) ) return false;

        if ( !isset( $this->data['location_latitude'] ) || is_null( $this->data['location_latitude'] ) || empty( $this->data['location_latitude'] )  )  return false;
        if ( !isset( $this->data['location_longitude'] ) || is_null( $this->data['location_longitude'] ) || empty( $this->data['location_longitude'] )  )  return false;

        // Get its self data from gmap entity JSON data
        $lat = $this->data['location_latitude'];
        $lng = $this->data['location_longitude'];
        WP_Log::debug( __METHOD__, ['$lat'=>$lat, '$lng'=>$lng], 'wp-sukellos-fw' );

        // Build Google array
        $gmap = array( 'lat'=>$lat, 'lng'=>$lng );

        update_field( $this->get_acf_field_name(), $gmap, $post_id );
    }
}
