<?php

namespace Sukellos;

use Sukellos\WPFw\Utils\WP_Log;

defined( 'ABSPATH' ) or exit;

/**
 * Reviews_Per_Score field Class
 *
 * @since 1.0.0
 */
class Reviews_Per_Score extends Field {

    // "reviews_per_score": {
    //		"1": 7,
    //		"2": 0,
    //		"3": 3,
    //		"4": 14,
    //		"5": 33
    //	},

    protected $field_id = 'reviews_per_score';
    protected $field_label = 'Reviews per score';

    /**
     * Get the specific ACF Custom Field definition
     */
    public function get_specific_acf_field_definition() {

        $sub_fields = array();
        for ($i=1; $i<=5; $i++) {

            $sub_fields[] = array(
                'key' => $this->get_acf_field_key().'_'.$i,
                'label' => ''.$i,
                'name' => $this->get_acf_field_name().'_'.$i,
                'aria-label' => '',
                'type' => 'number',
                'instructions' => '',
                'required' => 0,
                'conditional_logic' => 0,
                'wrapper' => array(
                    'width' => '',
                    'class' => '',
                    'id' => '',
                ),
                'default_value' => '',
                'min' => '',
                'max' => '',
                'placeholder' => '',
                'step' => '',
                'prepend' => '',
                'append' => '',
            );
        }

        return array(
            'aria-label' => '',
            'type' => 'group',
            'instructions' => '',
            'required' => 0,
            'conditional_logic' => 0,
            'wrapper' => array(
                'width' => '',
                'class' => '',
                'id' => '',
            ),
            'layout' => 'table',
            'sub_fields' => $sub_fields,
        );
    }

    /**
     * Insert the field as a WordPress ACF Custom Field
     *
     * MUST be called after set_data()
     *
     * MUST be overriden if the type is complex (other than simple text, url...)
     */
    public function update_acf_field( $post_id ) {

        if ( is_null( $this->data ) ) return false;

        // Get its self data from gmap entity JSON data
        if ( !isset( $this->data[$this->field_id] ) || is_null( $this->data[$this->field_id] ) || empty( $this->data[$this->field_id] )  )  return false;

        $self_data = $this->data[$this->field_id];
        WP_Log::debug( __METHOD__, ['field_id'=>$this->field_id, '$self_data'=>$self_data], 'wp-sukellos-fw' );

        $field_data = array();
        for ($i=1; $i<=5; $i++) {

            $field_data[$this->get_acf_field_name().'_'.$i] = $self_data[$i];
        }

        update_field( $this->get_acf_field_name(), $field_data, $post_id );
    }
}
