<?php

namespace Sukellos\ScrapioAPI;

use Sukellos\WPFw\Api\WP_API_JSON_Response;
use Exception;
use Sukellos\WPFw\Utils\WP_Log;

defined( 'ABSPATH' ) or exit;

/**
 *  Scrapio response object.
 *
 * @since 1.0.0
 */
class WP_Scrapio_API_Response extends WP_API_JSON_Response {


    /**
     * LEO2Click API Response constructor.
     *
     * @since 1.0.0
     *
     * @param string|object $raw_response a response as JSON object or JSON encoded string
     */
    public function __construct( $raw_response ) {

        $raw_response = is_object( $raw_response ) ? json_encode( $raw_response ) : $raw_response;

        parent::__construct( $raw_response );
    }


    /**
     * subscription
     *
     * @since 1.0.0
     *
     * @param type $raw true to retrieve raw data, otherwise false to decorate with specific class, eg. Product
     * @return WP_Scrapio_Subscription array of key:values
     */
    public function subscription( $raw = false ) {

        WP_Log::debug( __METHOD__, ['response data'=>$this->response_data], 'wp-sukellos-fw');

        // Is it OK ?
        $error = isset( $this->response_data->message ) && ( $this->response_data->message !== 'success' );

        if ( $error ) {
            
//            throw new Exception( $this->response_data->error, $this->code );
            throw new Exception( $this->response_data->message );
        }

        if ( $raw ) return $this->response_data;
        else {

            return new WP_Scrapio_Subscription( $this->response_data );
        }
    }

    /**
     * GET https://scrap.io/api/v1/gmap/types
     *
     * @since 1.0.0
     *
     * @param type $raw true to retrieve raw data, otherwise false to decorate with specific class, eg. Product
     * @return WP_Scrapio_Types array of key:values
     */
    public function gmap_types( $raw = false ) {

        WP_Log::debug( __METHOD__, ['response data'=>$this->response_data], 'wp-sukellos-fw');

        // Is it OK ?
        $error = isset( $this->response_data->message ) && ( $this->response_data->message !== 'success' );

        if ( $error ) {

//            throw new Exception( $this->response_data->error, $this->code );
            throw new Exception( $this->response_data->message );
        }

        if ( $raw ) return $this->response_data;
        else {

            return new WP_Scrapio_Types( $this->response_data );
        }
    }

    /**
     * GET https://scrap.io/api/v1/gmap/locations
     *
     * @since 1.0.0
     *
     * @param type $raw true to retrieve raw data, otherwise false to decorate with specific class, eg. Product
     * @return WP_Scrapio_Locations array of key:values
     */
    public function gmap_locations( $raw = false ) {

        WP_Log::debug( __METHOD__, ['response data'=>$this->response_data], 'wp-sukellos-fw');

        // Is it OK ?
        $error = isset( $this->response_data->message ) && ( $this->response_data->message !== 'success' );

        if ( $error ) {

//            throw new Exception( $this->response_data->error, $this->code );
            throw new Exception( $this->response_data->message );
        }

        if ( $raw ) return $this->response_data;
        else {

            return new WP_Scrapio_Locations( $this->response_data );
        }
    }

    /**
     * GET https://scrap.io/api/v1/gmap/place
     *
     * @since 1.0.0
     *
     * @param type $raw true to retrieve raw data, otherwise false to decorate with specific class, eg. Product
     * @return type array of key:values
     */
    public function gmap_place( $raw = false ) {

        //The above code returns JSON structured like this:
        //{
        //    "meta": {
        //        "found": true,
        //        "status": "updating"
        //    },
        //    "data": {
        //        "google_id": "0x3e5f43348a67e24b:0xff45e502e1ceb7e2",
        //        "name": "Burj Khalifa",
        //        "types": [
        //            {
        //                "type": "landmark",
        //                "deleted": false,
        //                "is_main": true
        //            },
        //            {
        //                "type": "tourist-attraction",
        //                "deleted": false,
        //                "is_main": false
        //            }
        //        ],
        //        "is_closed": false,
        //        "descriptions": [
        //            "160-story skyscraper & observation deck",
        //            "Spired 828-meter skyscraper with a viewing deck, restaurant, hotel and offices and 11-hectare park."
        //        ],
        //        "website": "http://www.burjkhalifa.ae",
        //        "phone": "+971 4 888 8888",
        //        "phone_international": "+97148888888",
        //        "timezone": "Asia/Dubai",
        //        "location_full_address": "Burj Khalifa - 1 Sheikh Mohammed bin Rashid Blvd - Downtown Dubai - Dubai - United Arab Emirates",
        //        "location_borough": "Downtown Dubai",
        //        "location_street_1": "1 Sheikh Mohammed bin Rashid Blvd",
        //        "location_street_2": "1 Sheikh Mohammed bin Rashid Blvd",
        //        "location_city": null,
        //        "location_postal_code": null,
        //        "location_state": "Dubai",
        //        "location_latitude": "25.197197",
        //        "location_longitude": "55.2743764",
        //        "location_country_code": "AE",
        //        "location_admin1_code": "03",
        //        "location_admin2_code": null,
        //        "link": "https://www.google.com/maps/place/Burj+Khalifa/data=!4m2!3m1!1s0x3e5f43348a67e24b:0xff45e502e1ceb7e2!10m1!1e1",
        //        "place_id": "ChIJS-JnijRDXz4R4rfO4QLlRf8",
        //        "owner_name": "Burj Khalifa",
        //        "owner_id": "104965669872746574451",
        //        "price_range": null,
        //        "reviews_id": "-52384020103776286",
        //        "reviews_count": 106266,
        //        "reviews_rating": 4.7,
        //        "reviews_per_score": {
        //            "1": 3303,
        //            "2": 1183,
        //            "3": 2803,
        //            "4": 10414,
        //            "5": 88563
        //        },
        //        "photos_count": "377083+",
        //        "photos": {
        //            "0": "https://lh5.googleusercontent.com/p/AF1QipOCRDiPjJ0c7WKYsuiOF9WkCiXv8cQNp_YeLEZo",
        //            "2": "https://lh5.googleusercontent.com/p/AF1QipPEPJrgd49pNpmeBF3tvZTgut9SZ_q3K5tK1lDz"
        //        },
        //        "characteristics": {
        //            "accessibility": {
        //                "wheelchair-accessible-entrance": "has-wheelchair-accessible-entrance"
        //            }
        //        },
        //        "occupancy": {
        //            "monday": {
        //                "4 AM": "usually-not-busy",
        //                "5 AM": "usually-not-busy",
        //                "6 AM": "usually-not-busy",
        //                "7 AM": "usually-not-busy",
        //                "8 AM": "usually-not-too-busy",
        //                "9 AM": "usually-not-too-busy",
        //                "10 AM": "usually-a-little-busy",
        //                "11 AM": "usually-a-little-busy",
        //                "12 PM": "usually-as-busy-as-it-gets",
        //                "1 PM": "usually-as-busy-as-it-gets",
        //                "2 PM": "usually-as-busy-as-it-gets",
        //                "3 PM": "usually-as-busy-as-it-gets",
        //                "4 PM": "usually-as-busy-as-it-gets",
        //                "5 PM": "usually-as-busy-as-it-gets",
        //                "6 PM": "usually-as-busy-as-it-gets",
        //                "7 PM": "usually-as-busy-as-it-gets",
        //                "8 PM": "usually-as-busy-as-it-gets",
        //                "9 PM": "usually-a-little-busy",
        //                "10 PM": "usually-a-little-busy",
        //                "11 PM": "usually-not-too-busy",
        //                "12 AM": "usually-not-busy",
        //                "1 AM": "usually-not-busy",
        //                "2 AM": "usually-not-busy",
        //                "3 AM": "usually-not-busy"
        //            },
        //            "tuesday": {
        //                "4 AM": "usually-not-busy",
        //                "5 AM": "usually-not-busy",
        //                "6 AM": "usually-not-busy",
        //                "7 AM": "usually-not-too-busy",
        //                "8 AM": "usually-not-too-busy",
        //                "9 AM": "usually-not-too-busy",
        //                "10 AM": "usually-a-little-busy",
        //                "11 AM": "usually-a-little-busy",
        //                "12 PM": "usually-as-busy-as-it-gets",
        //                "1 PM": "usually-as-busy-as-it-gets",
        //                "2 PM": "usually-as-busy-as-it-gets",
        //                "3 PM": "usually-as-busy-as-it-gets",
        //                "4 PM": "usually-as-busy-as-it-gets",
        //                "5 PM": "usually-as-busy-as-it-gets",
        //                "6 PM": "usually-as-busy-as-it-gets",
        //                "7 PM": "usually-as-busy-as-it-gets",
        //                "8 PM": "usually-as-busy-as-it-gets",
        //                "9 PM": "usually-a-little-busy",
        //                "10 PM": "usually-a-little-busy",
        //                "11 PM": "usually-not-too-busy",
        //                "12 AM": "usually-not-too-busy",
        //                "1 AM": "usually-not-busy",
        //                "2 AM": "usually-not-busy",
        //                "3 AM": "usually-not-busy"
        //            },
        //            "wednesday": {
        //                "4 AM": "usually-not-busy",
        //                "5 AM": "usually-not-busy",
        //                "6 AM": "usually-not-busy",
        //                "7 AM": "usually-not-too-busy",
        //                "8 AM": "usually-not-too-busy",
        //                "9 AM": "usually-not-too-busy",
        //                "10 AM": "usually-a-little-busy",
        //                "11 AM": "usually-a-little-busy",
        //                "12 PM": "usually-a-little-busy",
        //                "1 PM": "usually-as-busy-as-it-gets",
        //                "2 PM": "usually-as-busy-as-it-gets",
        //                "3 PM": "usually-as-busy-as-it-gets",
        //                "4 PM": "usually-as-busy-as-it-gets",
        //                "5 PM": "usually-as-busy-as-it-gets",
        //                "6 PM": "usually-as-busy-as-it-gets",
        //                "7 PM": "usually-as-busy-as-it-gets",
        //                "8 PM": "usually-as-busy-as-it-gets",
        //                "9 PM": "usually-a-little-busy",
        //                "10 PM": "usually-not-too-busy",
        //                "11 PM": "usually-not-too-busy",
        //                "12 AM": "usually-not-busy",
        //                "1 AM": "usually-not-busy",
        //                "2 AM": "usually-not-busy",
        //                "3 AM": "usually-not-busy"
        //            },
        //            "thursday": {
        //                "4 AM": "usually-not-busy",
        //                "5 AM": "usually-not-busy",
        //                "6 AM": "usually-not-busy",
        //                "7 AM": "usually-not-too-busy",
        //                "8 AM": "usually-not-too-busy",
        //                "9 AM": "usually-not-too-busy",
        //                "10 AM": "usually-a-little-busy",
        //                "11 AM": "usually-a-little-busy",
        //                "12 PM": "usually-as-busy-as-it-gets",
        //                "1 PM": "usually-as-busy-as-it-gets",
        //                "2 PM": "usually-as-busy-as-it-gets",
        //                "3 PM": "usually-as-busy-as-it-gets",
        //                "4 PM": "usually-as-busy-as-it-gets",
        //                "5 PM": "usually-as-busy-as-it-gets",
        //                "6 PM": "usually-as-busy-as-it-gets",
        //                "7 PM": "usually-as-busy-as-it-gets",
        //                "8 PM": "usually-as-busy-as-it-gets",
        //                "9 PM": "usually-a-little-busy",
        //                "10 PM": "usually-a-little-busy",
        //                "11 PM": "usually-not-too-busy",
        //                "12 AM": "usually-not-too-busy",
        //                "1 AM": "usually-not-busy",
        //                "2 AM": "usually-not-busy",
        //                "3 AM": "usually-not-busy"
        //            },
        //            "friday": {
        //                "4 AM": "usually-not-busy",
        //                "5 AM": "usually-not-busy",
        //                "6 AM": "usually-not-busy",
        //                "7 AM": "usually-not-too-busy",
        //                "8 AM": "usually-not-too-busy",
        //                "9 AM": "usually-not-too-busy",
        //                "10 AM": "usually-a-little-busy",
        //                "11 AM": "usually-a-little-busy",
        //                "12 PM": "usually-a-little-busy",
        //                "1 PM": "usually-as-busy-as-it-gets",
        //                "2 PM": "usually-as-busy-as-it-gets",
        //                "3 PM": "usually-as-busy-as-it-gets",
        //                "4 PM": "usually-as-busy-as-it-gets",
        //                "5 PM": "usually-as-busy-as-it-gets",
        //                "6 PM": "usually-as-busy-as-it-gets",
        //                "7 PM": "usually-as-busy-as-it-gets",
        //                "8 PM": "usually-as-busy-as-it-gets",
        //                "9 PM": "usually-a-little-busy",
        //                "10 PM": "usually-a-little-busy",
        //                "11 PM": "usually-not-too-busy",
        //                "12 AM": "usually-not-too-busy",
        //                "1 AM": "usually-not-busy",
        //                "2 AM": "usually-not-busy",
        //                "3 AM": "usually-not-busy"
        //            },
        //            "saturday": {
        //                "4 AM": "usually-not-busy",
        //                "5 AM": "usually-not-busy",
        //                "6 AM": "usually-not-busy",
        //                "7 AM": "usually-not-too-busy",
        //                "8 AM": "usually-not-too-busy",
        //                "9 AM": "usually-not-too-busy",
        //                "10 AM": "usually-a-little-busy",
        //                "11 AM": "usually-a-little-busy",
        //                "12 PM": "usually-a-little-busy",
        //                "1 PM": "usually-as-busy-as-it-gets",
        //                "2 PM": "usually-as-busy-as-it-gets",
        //                "3 PM": "usually-as-busy-as-it-gets",
        //                "4 PM": "usually-as-busy-as-it-gets",
        //                "5 PM": "usually-as-busy-as-it-gets",
        //                "6 PM": "usually-as-busy-as-it-gets",
        //                "7 PM": "usually-as-busy-as-it-gets",
        //                "8 PM": "usually-as-busy-as-it-gets",
        //                "9 PM": "usually-a-little-busy",
        //                "10 PM": "usually-a-little-busy",
        //                "11 PM": "usually-not-too-busy",
        //                "12 AM": "usually-not-too-busy",
        //                "1 AM": "usually-not-busy",
        //                "2 AM": "usually-not-busy",
        //                "3 AM": "usually-not-busy"
        //            },
        //            "sunday": {
        //                "4 AM": "usually-not-busy",
        //                "5 AM": "usually-not-busy",
        //                "6 AM": "usually-not-busy",
        //                "7 AM": "usually-not-busy",
        //                "8 AM": "usually-not-too-busy",
        //                "9 AM": "usually-not-too-busy",
        //                "10 AM": "usually-not-too-busy",
        //                "11 AM": "usually-a-little-busy",
        //                "12 PM": "usually-a-little-busy",
        //                "1 PM": "usually-as-busy-as-it-gets",
        //                "2 PM": "usually-as-busy-as-it-gets",
        //                "3 PM": "usually-as-busy-as-it-gets",
        //                "4 PM": "usually-as-busy-as-it-gets",
        //                "5 PM": "usually-as-busy-as-it-gets",
        //                "6 PM": "usually-as-busy-as-it-gets",
        //                "7 PM": "usually-as-busy-as-it-gets",
        //                "8 PM": "usually-as-busy-as-it-gets",
        //                "9 PM": "usually-a-little-busy",
        //                "10 PM": "usually-not-too-busy",
        //                "11 PM": "usually-not-too-busy",
        //                "12 AM": "usually-not-busy",
        //                "1 AM": "usually-not-busy",
        //                "2 AM": "usually-not-busy",
        //                "3 AM": "usually-not-busy"
        //            }
        //        },
        //        "is_claimed": true,
        //        "working_hours": {
        //            "monday": "open-24-hours",
        //            "tuesday": "open-24-hours",
        //            "wednesday": "open-24-hours",
        //            "thursday": "open-24-hours",
        //            "friday": "open-24-hours",
        //            "saturday": "open-24-hours",
        //            "sunday": "open-24-hours"
        //        },
        //        "status": "pending",
        //        "scraped_at": "2022-06-12T12:43:50.000000Z",
        //        "first_seen_at": "2021-04-12T16:25:50.000000Z",
        //        "website_data": {
        //            "url": "http://www.burjkhalifa.ae",
        //            "domain": "burjkhalifa.ae",
        //            "is_responding": true,
        //            "is_empty": null,
        //            "title": "Buy Online & Book Now to Visit the Burj Khalifa | Burj Khalifa",
        //            "meta_keywords": null,
        //            "meta_description": "Burj Khalifa is the tallest tower in the world and it’s one of the top attractions to visit in Dubai. Visit our website and book your Burj Khalifa tickets!",
        //            "meta_og_title": "Buy Online & Book Now to Visit the Burj Khalifa | Burj Khalifa",
        //            "meta_og_image": null,
        //            "meta_generator": null,
        //            "lang": "/e",
        //            "contact_pages": [
        //                "http://www.burjkhalifa.ae/en/contact-us",
        //                "http://www.burjkhalifa.ae/ar/contact-us"
        //            ],
        //            "facebook": [
        //                "https://facebook.com/burjkhalifa"
        //            ],
        //            "youtube": [
        //                "https://youtube.com/channel/UCKvfrKJ2qRF4Aw487-dCzUw"
        //            ],
        //            "twitter": [
        //                "https://twitter.com/burjkhalifa"
        //            ],
        //            "instagram": [
        //                "https://instagram.com/burjkhalifa"
        //            ],
        //            "linkedin": null,
        //            "technologies": [
        //                "Google Tag Manager"
        //            ],
        //            "ad_pixels": [
        //                "Google Tag Manager"
        //            ],
        //            "emails": [
        //                {
        //                    "email": "reception@theburjclub.com",
        //                    "sources": [
        //                        "https://www.burjkhalifa.ae/en/the-burj-club/gym/",
        //                        "https://www.burjkhalifa.ae/en/the-burj-club/spa/",
        //                        "https://www.burjkhalifa.ae/en/the-burj-club/rooftop/"
        //                    ]
        //                },
        //                {
        //                    "email": "customer.privacy@emaar.ae",
        //                    "sources": [
        //                        "https://www.burjkhalifa.ae/en/privacy-policy/"
        //                    ]
        //                },
        //                {
        //                    "email": "artanddesign@burjkhalifa.ae",
        //                    "sources": [
        //                        "https://www.burjkhalifa.ae/en/open-call/"
        //                    ]
        //                },
        //                {
        //                    "email": "schools@emaar.ae",
        //                    "sources": [
        //                        "https://www.burjkhalifa.ae/en/schools/"
        //                    ]
        //                },
        //                {
        //                    "email": "info@atthetop.ae",
        //                    "sources": [
        //                        "https://www.burjkhalifa.ae/en/events/"
        //                    ]
        //                }
        //            ],
        //            "phones": [
        //                {
        //                    "phone": "+97148883900",
        //                    "sources": [
        //                        "https://www.burjkhalifa.ae/en/the-burj-club/gym/",
        //                        "https://www.burjkhalifa.ae/en/the-burj-club/spa/",
        //                        "https://www.burjkhalifa.ae/en/the-burj-club/rooftop/"
        //                    ]
        //                },
        //                {
        //                    "phone": "+971480036227",
        //                    "sources": [
        //                        "https://www.burjkhalifa.ae/en/privacy-policy/"
        //                    ]
        //                }
        //            ],
        //            "status": "completed",
        //            "scraped_at": "2022-06-12T12:48:07.000000Z"
        //        }
        //    }
        //}

        WP_Log::debug( __METHOD__, ['response data'=>$this->response_data], 'wp-sukellos-fw');

        // Is it OK ?
        /*
        $success = isset( $this->response_data->method ) && 'SHOP_atoo_shop_list' === $this->response_data->method;

        if ( ! $success && isset( $this->response_data->error ) ) {

//            throw new Exception( $this->response_data->error, $this->code );
            throw new Exception( $this->response_data->error->id );
        }*/

        return $this->response_data;
    }


    /**
     * GET https://scrap.io/api/v1/gmap/search
     *
     * @since 1.0.0
     *
     * @param type $raw true to retrieve raw data, otherwise false to decorate with specific class, eg. Product
     * @return type array of key:values
     */
    public function gmap_search( $raw = false ) {

        WP_Log::debug( __METHOD__, ['response data'=>$this->response_data], 'wp-sukellos-fw');

        // Is it OK ?
        $error = isset( $this->response_data->message ) && ( $this->response_data->message !== 'success' );

        if ( $error ) {

//            throw new Exception( $this->response_data->error, $this->code );
            throw new Exception( $this->response_data->message );
        }

        if ( $raw ) return $this->response_data;
        else {

            return new WP_Scrapio_Search( $this->response_data );
        }
    }

    /**
     * GET https://scrap.io/api/v1/gmap/enrich
     *
     * @since 1.0.0
     *
     * @param type $raw true to retrieve raw data, otherwise false to decorate with specific class, eg. Product
     * @return type array of key:values
     */
    public function gmap_enrich( $raw = false ) {

        //The above code returns JSON structured like this:
        //{
        //    "meta": {
        //        "count": "16",
        //        "status": "completed",
        //        "next_cursor": "eyJnbWFwX3BsYWNlX2lkIjo0NTE0NjQsIl9wb2ludHNUb05leHRJdGVtcyI6dHJ1ZX0",
        //        "previous_cursor": null,
        //        "per_page": 10,
        //        "has_more_pages": true
        //    },
        //    "data": [
        //        {
        //            "google_id": "0x89c259a17dedfa2b:0x6f033e0043942344",
        //            "name": "SUGARFISH by sushi nozawa",
        //            "types": [
        //                {
        //                    "type": "restaurant",
        //                    "deleted": false,
        //                    "is_main": true
        //                },
        //                {
        //                    "type": "sushi-restaurant",
        //                    "deleted": false,
        //                    "is_main": false
        //                }
        //            ],
        //            "is_closed": false,
        //            "descriptions": [
        //                "SUGARFISH, a food-centric full-service restaurant, features a unique omakase-style service based on Nozawa’s 50 plus years of experience in Japan and the US. The menu features only tradition-based sushi of the highest quality, offered in four \"Trust Me®\" options, as well as an array of a la carte sashimi, sushi, and hand rolls made with carefully sourced fish, warm and loosely-packed rice, and crisp nori. SUGARFISH has locations in Los Angeles and New York City. For more information follow SUGARFISH on Instagram, Facebook and Twitter.",
        //                "Acclaimed sushi & sake destination",
        //                "Celebrated local sushi chain serving traditional rolls & sake in a chic, intimate space."
        //            ],
        //            "website": "https://sugarfishsushi.com/locations/flatiron",
        //            "phone": "+1 347-705-8100",
        //            "phone_international": "+13477058100",
        //            "timezone": "America/New_York",
        //            "location_full_address": "SUGARFISH by sushi nozawa, 33 E 20th St, New York, NY 10003, United States",
        //            "location_borough": "Manhattan",
        //            "location_street_1": "33 E 20th St",
        //            "location_street_2": "33 E 20th St",
        //            "location_city": "New York",
        //            "location_postal_code": "10003",
        //            "location_state": "New York",
        //            "location_latitude": "40.739001",
        //            "location_longitude": "-73.9888323",
        //            "location_country_code": "US",
        //            "location_admin1_code": "NY",
        //            "location_admin2_code": "061",
        //            "link": "https://www.google.com/maps/place/SUGARFISH+by+sushi+nozawa/data=!4m2!3m1!1s0x89c259a17dedfa2b:0x6f033e0043942344!10m1!1e1",
        //            "place_id": "ChIJK_rtfaFZwokRRCOUQwA-A28",
        //            "owner_name": "SUGARFISH by sushi nozawa",
        //            "owner_id": "100376796693654910584",
        //            "price_range": "$$$",
        //            "reviews_id": "7999305533994836804",
        //            "reviews_count": 1401,
        //            "reviews_rating": 4.5,
        //            "reviews_per_score": {
        //                "1": 78,
        //                "2": 28,
        //                "3": 67,
        //                "4": 194,
        //                "5": 1034
        //            },
        //            "photos_count": "1179+",
        //            "photos": {
        //                "0": "https://lh5.googleusercontent.com/p/AF1QipND93_nJUKC8a41_q3hsBPb4-PAtQbV-rvH0riE",
        //                "2": "https://lh5.googleusercontent.com/p/AF1QipOnX8thoIENmUO6Soi9ev88XaSHO0bVZQVcWFNC"
        //            },
        //            "characteristics": {
        //                "service-options": {
        //                    "delivery": "offers-delivery",
        //                    "takeout": "offers-takeout",
        //                    "dine-in": "serves-dine-in"
        //                },
        //                "health-and-safety": {
        //                    "staff-required-to-disinfect-surfaces-between-visits": "staff-required-to-disinfect-surfaces-between-visits"
        //                },
        //                "highlights": {
        //                    "great-tea-selection": "has-great-tea-selection"
        //                },
        //                "popular-for": {
        //                    "lunch": "popular-for-lunch",
        //                    "dinner": "popular-for-dinner",
        //                    "solo-dining": "good-for-solo-dining"
        //                },
        //                "accessibility": {
        //                    "wheelchair-accessible-entrance": "has-wheelchair-accessible-entrance",
        //                    "wheelchair-accessible-parking-lot": "no-wheelchair-accessible-parking-lot"
        //                },
        //                "offerings": {
        //                    "alcohol": "serves-alcohol",
        //                    "beer": "serves-beer",
        //                    "healthy-options": "serves-healthy-options",
        //                    "small-plates": "serves-small-plates",
        //                    "wine": "serves-wine"
        //                },
        //                "dining-options": {
        //                    "lunch": "serves-lunch",
        //                    "dinner": "serves-dinner",
        //                    "seating": "has-seating"
        //                },
        //                "atmosphere": {
        //                    "casual": "casual",
        //                    "cozy": "cozy",
        //                    "upscale": "upscale"
        //                },
        //                "crowd": {
        //                    "tourists": "popular-with-tourists"
        //                },
        //                "planning": {
        //                    "usually-a-wait": "usually-has-a-wait"
        //                },
        //                "payments": {
        //                    "debit-cards": "accepts-debit-cards"
        //                }
        //            },
        //            "occupancy": {
        //                "monday": null,
        //                "tuesday": {
        //                    "6 a.m.": "closed",
        //                    "7 a.m.": "closed",
        //                    "8 a.m.": "closed",
        //                    "9 a.m.": "closed",
        //                    "10 a.m.": "closed",
        //                    "11 a.m.": "usually-not-too-busy",
        //                    "12 p.m.": "usually-not-too-busy",
        //                    "1 p.m.": "usually-not-too-busy",
        //                    "2 p.m.": "usually-a-little-busy",
        //                    "3 p.m.": "usually-a-little-busy",
        //                    "4 p.m.": "usually-a-little-busy",
        //                    "5 p.m.": "usually-a-little-busy",
        //                    "6 p.m.": "usually-as-busy-as-it-gets",
        //                    "7 p.m.": "usually-as-busy-as-it-gets",
        //                    "8 p.m.": "usually-a-little-busy",
        //                    "9 p.m.": "usually-a-little-busy",
        //                    "10 p.m.": "usually-not-too-busy",
        //                    "11 p.m.": "closed"
        //                },
        //                "wednesday": {
        //                    "6 a.m.": "closed",
        //                    "7 a.m.": "closed",
        //                    "8 a.m.": "closed",
        //                    "9 a.m.": "closed",
        //                    "10 a.m.": "closed",
        //                    "11 a.m.": "usually-not-too-busy",
        //                    "12 p.m.": "usually-not-too-busy",
        //                    "1 p.m.": "usually-not-too-busy",
        //                    "2 p.m.": "usually-a-little-busy",
        //                    "3 p.m.": "usually-a-little-busy",
        //                    "4 p.m.": "usually-a-little-busy",
        //                    "5 p.m.": "usually-a-little-busy",
        //                    "6 p.m.": "usually-as-busy-as-it-gets",
        //                    "7 p.m.": "usually-as-busy-as-it-gets",
        //                    "8 p.m.": "usually-a-little-busy",
        //                    "9 p.m.": "usually-a-little-busy",
        //                    "10 p.m.": "usually-not-too-busy",
        //                    "11 p.m.": "closed"
        //                },
        //                "thursday": {
        //                    "6 a.m.": "closed",
        //                    "7 a.m.": "closed",
        //                    "8 a.m.": "closed",
        //                    "9 a.m.": "closed",
        //                    "10 a.m.": "closed",
        //                    "11 a.m.": "usually-not-too-busy",
        //                    "12 p.m.": "usually-a-little-busy",
        //                    "1 p.m.": "usually-a-little-busy",
        //                    "2 p.m.": "usually-a-little-busy",
        //                    "3 p.m.": "usually-a-little-busy",
        //                    "4 p.m.": "usually-a-little-busy",
        //                    "5 p.m.": "usually-a-little-busy",
        //                    "6 p.m.": "usually-a-little-busy",
        //                    "7 p.m.": "usually-as-busy-as-it-gets",
        //                    "8 p.m.": "usually-a-little-busy",
        //                    "9 p.m.": "usually-a-little-busy",
        //                    "10 p.m.": "usually-not-too-busy",
        //                    "11 p.m.": "closed"
        //                },
        //                "friday": {
        //                    "6 a.m.": "closed",
        //                    "7 a.m.": "closed",
        //                    "8 a.m.": "closed",
        //                    "9 a.m.": "closed",
        //                    "10 a.m.": "closed",
        //                    "11 a.m.": "usually-not-too-busy",
        //                    "12 p.m.": "usually-a-little-busy",
        //                    "1 p.m.": "usually-a-little-busy",
        //                    "2 p.m.": "usually-a-little-busy",
        //                    "3 p.m.": "usually-a-little-busy",
        //                    "4 p.m.": "usually-a-little-busy",
        //                    "5 p.m.": "usually-a-little-busy",
        //                    "6 p.m.": "usually-as-busy-as-it-gets",
        //                    "7 p.m.": "usually-as-busy-as-it-gets",
        //                    "8 p.m.": "usually-as-busy-as-it-gets",
        //                    "9 p.m.": "usually-as-busy-as-it-gets",
        //                    "10 p.m.": "usually-a-little-busy",
        //                    "11 p.m.": "usually-not-too-busy"
        //                },
        //                "saturday": {
        //                    "6 a.m.": "closed",
        //                    "7 a.m.": "closed",
        //                    "8 a.m.": "closed",
        //                    "9 a.m.": "closed",
        //                    "10 a.m.": "closed",
        //                    "11 a.m.": "usually-not-too-busy",
        //                    "12 p.m.": "usually-not-too-busy",
        //                    "1 p.m.": "usually-a-little-busy",
        //                    "2 p.m.": "usually-a-little-busy",
        //                    "3 p.m.": "usually-a-little-busy",
        //                    "4 p.m.": "usually-a-little-busy",
        //                    "5 p.m.": "usually-a-little-busy",
        //                    "6 p.m.": "usually-as-busy-as-it-gets",
        //                    "7 p.m.": "usually-as-busy-as-it-gets",
        //                    "8 p.m.": "usually-a-little-busy",
        //                    "9 p.m.": "usually-a-little-busy",
        //                    "10 p.m.": "usually-a-little-busy",
        //                    "11 p.m.": "usually-not-too-busy"
        //                },
        //                "sunday": {
        //                    "6 a.m.": "closed",
        //                    "7 a.m.": "closed",
        //                    "8 a.m.": "closed",
        //                    "9 a.m.": "closed",
        //                    "10 a.m.": "closed",
        //                    "11 a.m.": "closed",
        //                    "12 p.m.": "usually-not-too-busy",
        //                    "1 p.m.": "usually-not-too-busy",
        //                    "2 p.m.": "usually-a-little-busy",
        //                    "3 p.m.": "usually-a-little-busy",
        //                    "4 p.m.": "usually-a-little-busy",
        //                    "5 p.m.": "usually-a-little-busy",
        //                    "6 p.m.": "usually-a-little-busy",
        //                    "7 p.m.": "usually-a-little-busy",
        //                    "8 p.m.": "usually-a-little-busy",
        //                    "9 p.m.": "usually-not-too-busy",
        //                    "10 p.m.": "usually-not-too-busy",
        //                    "11 p.m.": "closed"
        //                }
        //            },
        //            "is_claimed": true,
        //            "working_hours": {
        //                "monday": "closed",
        //                "tuesday": "1130am-11pm",
        //                "wednesday": "1130am-11pm",
        //                "thursday": "1130am-11pm",
        //                "friday": "1130am-12am",
        //                "saturday": "1130am-12am",
        //                "sunday": "12-11pm"
        //            },
        //            "status": "completed",
        //            "scraped_at": "2022-07-04T10:24:57.000000Z",
        //            "first_seen_at": "2021-04-12T16:25:50.000000Z",
        //            "website_data": {
        //                "url": "https://sugarfishsushi.com/locations/flatiron",
        //                "domain": "sugarfishsushi.com",
        //                "is_responding": true,
        //                "is_empty": null,
        //                "title": "Flatiron – SUGARFISH",
        //                "meta_keywords": null,
        //                "meta_description": null,
        //                "meta_og_title": null,
        //                "meta_og_image": null,
        //                "meta_generator": "WordPress 5.8.4",
        //                "lang": "en",
        //                "contact_pages": [
        //                    "https://sugarfishsushi.com/contact-us"
        //                ],
        //                "facebook": [
        //                    "https://facebook.com/sugarfishsushi"
        //                ],
        //                "youtube": null,
        //                "twitter": [
        //                    "https://twitter.com/sugarfish"
        //                ],
        //                "instagram": [
        //                    "https://instagram.com/sugarfishbynozawa"
        //                ],
        //                "linkedin": null,
        //                "technologies": [
        //                    "Apache",
        //                    "Google Analytics",
        //                    "WordPress",
        //                    "PHP",
        //                    "MySQL"
        //                ],
        //                "ad_pixels": [
        //                    "Google Tag Manager"
        //                ],
        //                "emails": [
        //                    {
        //                        "email": "flatiron@sugarfishsushi.com",
        //                        "sources": [
        //                            "https://sugarfishsushi.com/locations/flatiron"
        //                        ]
        //                    },
        //                    {
        //                        "email": "eat@sugarfishsushi.com",
        //                        "sources": [
        //                            "https://sugarfishsushi.com/locations/flatiron"
        //                        ]
        //                    }
        //                ],
        //                "phones": null,
        //                "status": "completed",
        //                "scraped_at": "2022-07-04T10:24:53.000000Z"
        //            }
        //        },
        //        ...
        //    ]
        //}

        WP_Log::debug( __METHOD__, ['response data'=>$this->response_data], 'wp-sukellos-fw');

        // Is it OK ?
        /*
        $success = isset( $this->response_data->method ) && 'SHOP_atoo_shop_list' === $this->response_data->method;

        if ( ! $success && isset( $this->response_data->error ) ) {

//            throw new Exception( $this->response_data->error, $this->code );
            throw new Exception( $this->response_data->error->id );
        }*/

        return $this->response_data;
    }

    /**
     * GET https://scrap.io/api/v1/gmap/blacklist
     *
     * @since 1.0.0
     *
     * @param type $raw true to retrieve raw data, otherwise false to decorate with specific class, eg. Product
     * @return type array of key:values
     */
    public function blacklist( $raw = false ) {

        //The above code returns JSON structured like this:
        //[
        //    {
        //        "list": "my-list-1",
        //        "nb": 2
        //    },
        //    {
        //        "list": "my-list-2",
        //        "nb": 1
        //    }
        //]

        WP_Log::debug( __METHOD__, ['response data'=>$this->response_data], 'wp-sukellos-fw');

        // Is it OK ?
        /*
        $success = isset( $this->response_data->method ) && 'SHOP_atoo_shop_list' === $this->response_data->method;

        if ( ! $success && isset( $this->response_data->error ) ) {

//            throw new Exception( $this->response_data->error, $this->code );
            throw new Exception( $this->response_data->error->id );
        }*/

        return $this->response_data;
    }

    /**
     * POST https://scrap.io/api/v1/gmap/blacklist/{list-name}
     *
     * @since 1.0.0
     *
     * @param type $raw true to retrieve raw data, otherwise false to decorate with specific class, eg. Product
     * @return type array of key:values
     */
    public function blacklist_add( $raw = false ) {

        //The above code returns JSON structured like this:
        //{
        //    "message": "success"
        //}

        WP_Log::debug( __METHOD__, ['response data'=>$this->response_data], 'wp-sukellos-fw');

        // Is it OK ?
        /*
        $success = isset( $this->response_data->method ) && 'SHOP_atoo_shop_list' === $this->response_data->method;

        if ( ! $success && isset( $this->response_data->error ) ) {

//            throw new Exception( $this->response_data->error, $this->code );
            throw new Exception( $this->response_data->error->id );
        }*/

        return $this->response_data;
    }

    /**
     * DELETE https://scrap.io/api/v1/gmap/blacklist/{list-name}
     *
     * @since 1.0.0
     *
     * @param type $raw true to retrieve raw data, otherwise false to decorate with specific class, eg. Product
     * @return type array of key:values
     */
    public function blacklist_delete( $raw = false ) {

        //The above code returns JSON structured like this:
        //{
        //    "message": "success"
        //}

        WP_Log::debug( __METHOD__, ['response data'=>$this->response_data], 'wp-sukellos-fw');

        // Is it OK ?
        /*
        $success = isset( $this->response_data->method ) && 'SHOP_atoo_shop_list' === $this->response_data->method;

        if ( ! $success && isset( $this->response_data->error ) ) {

//            throw new Exception( $this->response_data->error, $this->code );
            throw new Exception( $this->response_data->error->id );
        }*/

        return $this->response_data;
    }
}
