<?php

namespace Sukellos\ScrapioAPI;

use InvalidArgumentException;

defined( 'ABSPATH' ) or exit;

class WP_Scrapio_API_Gmap_Search_Param {

    // Required
    // Parameter	Default	Required	Description
    // type		yes	ID of Gmap type to search for
    // country_code		yes	ISO Country code (FR, US, etc.)
    const TYPE = 'type';
    const COUNTRY_CODE = 'country_code';

    // Not required
    // Parameter	Default	Required	Description
    // per_page		no	Number of results per page (1, 10, 25 or 50)
    // skip_data		no	Boolean (0 = false / 1 = true) to indicate that you want to skip the data part of the response. When the data is skipped, it won't deduct any export credit.
    // cursor		no	Cursor pagination
    // admin1_code		no	ID of admin1 location to search for
    // admin2_code		no	ID of admin2 location to search for
    // city		no	ID of city to search for
    // postal_code		no	Postal code to search for
    // gmap_is_main_type		no	Boolean (0 = false / 1 = true)
    // gmap_is_closed		no	Boolean (0 = false / 1 = true)
    // gmap_has_website		no	Boolean (0 = false / 1 = true)
    // gmap_has_phone		no	Boolean (0 = false / 1 = true)
    // gmap_price_range		no	Price range, e.g. '$', '$$', '$$$' or '$$$$'
    // gmap_reviews_count_lte		no	Gmap reviews count less or equal than
    // gmap_reviews_count_lt		no	Gmap reviews count less than
    // gmap_reviews_count_gte		no	Gmap reviews count greater or equals than
    // gmap_reviews_count_gt		no	Gmap reviews count greater than
    // gmap_reviews_rating_lte		no	Gmap reviews rating less or equal than
    // gmap_reviews_rating_lt		no	Gmap reviews rating less than
    // gmap_reviews_rating_gte		no	Gmap reviews rating greater or equals than
    // gmap_reviews_rating_gt		no	Gmap reviews rating greater than
    // gmap_photos_count_lte		no	Gmap photos count less or equal than
    // gmap_photos_count_lt		no	Gmap photos count less than
    // gmap_photos_count_gte		no	Gmap photos count greater or equals than
    // gmap_photos_count_gt		no	Gmap photos count greater than
    // gmap_is_claimed		no	Boolean (0 = false / 1 = true)
    // website_has_title		no	Boolean (0 = false / 1 = true)
    // website_has_meta_keywords		no	Boolean (0 = false / 1 = true)
    // website_has_meta_description		no	Boolean (0 = false / 1 = true)
    // website_has_contact_pages		no	Boolean (0 = false / 1 = true)
    // website_has_emails		no	Boolean (0 = false / 1 = true)
    // website_has_phones		no	Boolean (0 = false / 1 = true)
    // website_has_facebook		no	Boolean (0 = false / 1 = true)
    // website_has_youtube		no	Boolean (0 = false / 1 = true)
    // website_has_twitter		no	Boolean (0 = false / 1 = true)
    // website_has_instagram		no	Boolean (0 = false / 1 = true)
    // website_has_linkedin		no	Boolean (0 = false / 1 = true)
    // website_has_ad_pixels		no	Boolean (0 = false / 1 = true)
    const PER_PAGE = 'per_page';
    const SKIP_DATA = 'skip_data';
    const CURSOR = 'cursor';
    const ADMIN1_CODE = 'admin1_code';
    const ADMIN2_CODE = 'admin2_code';
    const CITY = 'city';
    const POSTAL_CODE = 'postal_code';
    const GMAP_IS_MAIN_TYPE = 'gmap_is_main_type';
    const GMAP_IS_CLOSED = 'gmap_is_closed';
    const GMAP_HAS_WEBSITE = 'gmap_has_website';
    const GMAP_HAS_PHONE = 'gmap_has_phone';
    const GMAP_PRICE_RANGE = 'gmap_price_range';
    const GMAP_REVIEWS_COUNT_LTE = 'gmap_reviews_count_lte';
    const GMAP_REVIEWS_COUNT_LT = 'gmap_reviews_count_lt';
    const GMAP_REVIEWS_COUNT_GTE = 'gmap_reviews_count_gte';
    const GMAP_REVIEWS_COUNT_GT = 'gmap_reviews_count_gt';
    const GMAP_REVIEWS_RATING_LTE = 'gmap_reviews_rating_lte';
    const GMAP_REVIEWS_RATING_LT = 'gmap_reviews_rating_lt';
    const GMAP_REVIEWS_RATING_GTE = 'gmap_reviews_rating_gte';
    const GMAP_REVIEWS_RATING_GT = 'gmap_reviews_rating_gt';
    const GMAP_PHOTOS_COUNT_LTE = 'gmap_photos_count_lte';
    const GMAP_PHOTOS_COUNT_LT = 'gmap_photos_count_lt';
    const GMAP_PHOTOS_COUNT_GTE = 'gmap_photos_count_gte';
    const GMAP_PHOTOS_COUNT_GT = 'gmap_photos_count_gt';
    const GMAP_IS_CLAIMED = 'gmap_is_claimed';
    const WEBSITE_HAS_TITLE = 'website_has_title';
    const WEBSITE_HAS_META_KEYWORDS = 'website_has_meta_keywords';
    const WEBSITE_HAS_META_DESCRIPTION = 'website_has_meta_description';
    const WEBSITE_HAS_CONTACT_PAGES = 'website_has_contact_pages';
    const WEBSITE_HAS_EMAILS = 'website_has_emails';
    const WEBSITE_HAS_PHONES = 'website_has_phones';
    const WEBSITE_HAS_FACEBOOK = 'website_has_facebook';
    const WEBSITE_HAS_YOUTUBE = 'website_has_youtube';
    const WEBSITE_HAS_TWITTER = 'website_has_twitter';
    const WEBSITE_HAS_INSTAGRAM = 'website_has_instagram';
    const WEBSITE_HAS_LINKEDIN = 'website_has_linkedin';
    const WEBSITE_HAS_AD_PIXELS = 'website_has_ad_pixels';
    
    private static $auth_params = array(
        self::TYPE,
        self::COUNTRY_CODE,
        self::PER_PAGE,
        self::SKIP_DATA,
        self::CURSOR,
        self::ADMIN1_CODE,
        self::ADMIN2_CODE,
        self::CITY,
        self::POSTAL_CODE,
        self::GMAP_IS_MAIN_TYPE,
        self::GMAP_IS_CLOSED,
        self::GMAP_HAS_WEBSITE,
        self::GMAP_HAS_PHONE,
        self::GMAP_PRICE_RANGE,
        self::GMAP_REVIEWS_COUNT_LTE,
        self::GMAP_REVIEWS_COUNT_LT,
        self::GMAP_REVIEWS_COUNT_GTE,
        self::GMAP_REVIEWS_COUNT_GT,
        self::GMAP_REVIEWS_RATING_LTE,
        self::GMAP_REVIEWS_RATING_LT,
        self::GMAP_REVIEWS_RATING_GTE,
        self::GMAP_REVIEWS_RATING_GT,
        self::GMAP_PHOTOS_COUNT_LTE,
        self::GMAP_PHOTOS_COUNT_LT,
        self::GMAP_PHOTOS_COUNT_GTE,
        self::GMAP_PHOTOS_COUNT_GT,
        self::GMAP_IS_CLAIMED,
        self::WEBSITE_HAS_TITLE,
        self::WEBSITE_HAS_META_KEYWORDS,
        self::WEBSITE_HAS_META_DESCRIPTION,
        self::WEBSITE_HAS_CONTACT_PAGES,
        self::WEBSITE_HAS_EMAILS,
        self::WEBSITE_HAS_PHONES,
        self::WEBSITE_HAS_FACEBOOK,
        self::WEBSITE_HAS_YOUTUBE,
        self::WEBSITE_HAS_TWITTER,
        self::WEBSITE_HAS_INSTAGRAM,
        self::WEBSITE_HAS_LINKEDIN,
        self::WEBSITE_HAS_AD_PIXELS,
    );

    public static function validate_params( $params ) {

        foreach ( $params as $param => $value ) {

            if ( !in_array( $param, self::$auth_params ) ) {

                throw new InvalidArgumentException( 'Invalid gmap/search param provided.' );
            }
        }
    }
}
